@@ -34,7 +34,9 @@ import java.sql.Timestamp;
 
 import org.junit.Before;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 
+@Category(ParallelStatsDisabledTest.class)
 public class ArrayFillFunctionIT extends ParallelStatsDisabledIT {
 
     private String tableName;
