@@ -22,12 +22,20 @@ import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.ADD_DELET
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.ADD_VIEW_INDEX;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.CREATE_ADD;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.CREATE_DIVERGED_VIEW;
+import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.CREATE_OFFSET;
+import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.CREATE_ORDERED_GROUP_BY;
+import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.CREATE_ORDER_BY_NON_PK;
+import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.CREATE_UNORDERED_GROUP_BY;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.INDEX_REBUILD_ASYNC;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_ADD_DATA;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_ADD_DELETE;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_CREATE_ADD;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_CREATE_DIVERGED_VIEW;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_INDEX_REBUILD_ASYNC;
+import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_OFFSET;
+import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_ORDERED_GROUP_BY;
+import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_ORDER_BY_NON_PK;
+import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_UNORDERED_GROUP_BY;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_VIEW_INDEX;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.assertExpectedOutput;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.checkForPreConditions;
@@ -41,29 +49,29 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
 
-import java.io.IOException;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.util.Collection;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.client.TableDescriptor;
-import org.apache.phoenix.compat.hbase.CompatUtil;
 import org.apache.phoenix.coprocessor.SystemCatalogRegionObserver;
 import org.apache.phoenix.coprocessor.TaskMetaDataEndpoint;
+import org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.MavenCoordinates;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.jdbc.PhoenixDriver;
+import org.apache.phoenix.query.BaseTest;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.query.QueryServicesOptions;
 import org.apache.phoenix.schema.SystemTaskSplitPolicy;
 import org.apache.phoenix.util.PhoenixRuntime;
+import org.apache.phoenix.util.ServerUtil.ConnectionFactory;
 import org.junit.After;
+import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
@@ -84,21 +92,21 @@ import org.slf4j.LoggerFactory;
 public class BackwardCompatibilityIT {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(
-        BackwardCompatibilityIT.class);
+            BackwardCompatibilityIT.class);
 
-    private final String compatibleClientVersion;
+    private final MavenCoordinates compatibleClientVersion;
     private static Configuration conf;
     private static HBaseTestingUtility hbaseTestUtil;
     private static String zkQuorum;
     private static String url;
     private String tmpDir;
 
-    public BackwardCompatibilityIT(String compatibleClientVersion) {
+    public BackwardCompatibilityIT(MavenCoordinates compatibleClientVersion) {
         this.compatibleClientVersion = compatibleClientVersion;
     }
 
     @Parameters(name = "BackwardCompatibilityIT_compatibleClientVersion={0}")
-    public static synchronized Collection<String> data() throws Exception {
+    public static synchronized Collection<MavenCoordinates> data() throws Exception {
         return computeClientVersions();
     }
 
@@ -119,11 +127,11 @@ public class BackwardCompatibilityIT {
         DriverManager.registerDriver(PhoenixDriver.INSTANCE);
         checkForPreConditions(compatibleClientVersion, conf);
     }
-    
+
     @After
-    public void cleanUpAfterTest() throws Exception {
-        boolean refCountLeaked = CompatUtil.isAnyStoreRefCountLeaked(
-            hbaseTestUtil.getAdmin());
+    public synchronized void cleanUpAfterTest() throws Exception {
+        boolean refCountLeaked = BaseTest.isAnyStoreRefCountLeaked(hbaseTestUtil.getAdmin());
+        ConnectionFactory.shutdown();
         try {
             DriverManager.deregisterDriver(PhoenixDriver.INSTANCE);
         } finally {
@@ -327,7 +335,7 @@ public class BackwardCompatibilityIT {
         assertExpectedOutput(QUERY_CREATE_ADD);
 
         // Deletes with the new client
-        executeQueriesWithCurrentVersion(ADD_DELETE,url, NONE);
+        executeQueriesWithCurrentVersion(ADD_DELETE, url, NONE);
         executeQueriesWithCurrentVersion(QUERY_ADD_DELETE, url, NONE);
         assertExpectedOutput(QUERY_ADD_DELETE);
     }
@@ -337,7 +345,7 @@ public class BackwardCompatibilityIT {
         executeQueryWithClientVersion(compatibleClientVersion,
             CREATE_DIVERGED_VIEW, zkQuorum);
 
-        String[] versionArr = compatibleClientVersion.split("\\.");
+        String[] versionArr = compatibleClientVersion.getVersion().split("\\.");
         int majorVersion = Integer.parseInt(versionArr[0]);
         int minorVersion = Integer.parseInt(versionArr[1]);
         org.apache.hadoop.hbase.client.Connection conn = null;
@@ -379,12 +387,11 @@ public class BackwardCompatibilityIT {
             TaskMetaDataEndpoint.class.getName()));
         assertExpectedOutput(QUERY_CREATE_DIVERGED_VIEW);
         admin.close();
-        conn.close();
     }
 
     @Test
     public void testSystemTaskCreationWithIndexAsyncRebuild() throws Exception {
-        String[] versionArr = compatibleClientVersion.split("\\.");
+        String[] versionArr = compatibleClientVersion.getVersion().split("\\.");
         int majorVersion = Integer.parseInt(versionArr[0]);
         int minorVersion = Integer.parseInt(versionArr[1]);
         // index async rebuild support min version check
@@ -412,11 +419,12 @@ public class BackwardCompatibilityIT {
     @Test
     public void testViewIndexIdCreatedWithOldClient() throws Exception {
         executeQueryWithClientVersion(compatibleClientVersion, ADD_VIEW_INDEX, zkQuorum);
-        try (org.apache.hadoop.hbase.client.Connection conn =
-                     hbaseTestUtil.getConnection(); Admin admin = conn.getAdmin()) {
-            HTableDescriptor tableDescriptor = admin.getTableDescriptor(
+        org.apache.hadoop.hbase.client.Connection conn = hbaseTestUtil.getConnection();
+        try (Admin admin = conn.getAdmin()) {
+            TableDescriptor tableDescriptor = admin.getDescriptor(
                     TableName.valueOf(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME));
-            assertFalse("Coprocessor " + SystemCatalogRegionObserver.class.getName()
+            //The oldest client we test is 5.1.0, which already adds SystemCatalogRegionObserver
+            assertTrue("Coprocessor " + SystemCatalogRegionObserver.class.getName()
                     + " has been added with compatible client version: "
                     + compatibleClientVersion, tableDescriptor.hasCoprocessor(
                     SystemCatalogRegionObserver.class.getName()));
@@ -424,7 +432,7 @@ public class BackwardCompatibilityIT {
             executeQueriesWithCurrentVersion(QUERY_VIEW_INDEX, url, NONE);
             assertExpectedOutput(QUERY_VIEW_INDEX);
 
-            tableDescriptor = admin.getTableDescriptor(
+            tableDescriptor = admin.getDescriptor(
                     TableName.valueOf(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME));
             assertTrue("Coprocessor " + SystemCatalogRegionObserver.class.getName()
                     + " has been added with compatible client version: "
@@ -439,4 +447,85 @@ public class BackwardCompatibilityIT {
         executeQueryWithClientVersion(compatibleClientVersion, QUERY_VIEW_INDEX, zkQuorum);
         assertExpectedOutput(QUERY_VIEW_INDEX);
     }
+
+    @Test
+    public void testUnorderedGroupByAddDataByOldClientReadByNewClient() throws Exception {
+        executeQueryWithClientVersion(compatibleClientVersion, CREATE_UNORDERED_GROUP_BY, zkQuorum);
+        executeQueriesWithCurrentVersion(QUERY_UNORDERED_GROUP_BY, url, NONE);
+        assertExpectedOutput(QUERY_UNORDERED_GROUP_BY);
+    }
+
+    @Test
+    public void testUnorderedGroupByAddDataByNewClientReadByOldClient() throws Exception {
+        executeQueriesWithCurrentVersion(CREATE_UNORDERED_GROUP_BY, url, NONE);
+        executeQueryWithClientVersion(compatibleClientVersion, QUERY_UNORDERED_GROUP_BY, zkQuorum);
+        assertExpectedOutput(QUERY_UNORDERED_GROUP_BY);
+    }
+
+    @Test
+    public void testOrderedGroupByAddDataByOldClientReadByNewClient() throws Exception {
+        executeQueryWithClientVersion(compatibleClientVersion, CREATE_ORDERED_GROUP_BY, zkQuorum);
+        executeQueriesWithCurrentVersion(QUERY_ORDERED_GROUP_BY, url, NONE);
+        assertExpectedOutput(QUERY_ORDERED_GROUP_BY);
+    }
+
+    @Test
+    public void testOrderedGroupByAddDataByNewClientReadByOldClient() throws Exception {
+        Assume.assumeTrue("compatible client version should be >= 5.1.3",
+                isClientCompatibleForOrderedGroupByQuery());
+        executeQueriesWithCurrentVersion(CREATE_ORDERED_GROUP_BY, url, NONE);
+        executeQueryWithClientVersion(compatibleClientVersion, QUERY_ORDERED_GROUP_BY, zkQuorum);
+        assertExpectedOutput(QUERY_ORDERED_GROUP_BY);
+    }
+
+    @Test
+    public void testOffsetAddDataByOldClientReadByNewClient() throws Exception {
+        executeQueryWithClientVersion(compatibleClientVersion, CREATE_OFFSET, zkQuorum);
+        executeQueriesWithCurrentVersion(QUERY_OFFSET, url, NONE);
+        assertExpectedOutput(QUERY_OFFSET);
+    }
+
+    @Test
+    public void testOffsetAddDataByNewClientReadByOldClient() throws Exception {
+        executeQueriesWithCurrentVersion(CREATE_OFFSET, url, NONE);
+        executeQueryWithClientVersion(compatibleClientVersion, QUERY_OFFSET, zkQuorum);
+        assertExpectedOutput(QUERY_OFFSET);
+    }
+
+    @Test
+    public void testOrderByNonPkAddDataByOldClientReadByNewClient() throws Exception {
+        executeQueryWithClientVersion(compatibleClientVersion, CREATE_ORDER_BY_NON_PK,
+                zkQuorum);
+        executeQueriesWithCurrentVersion(QUERY_ORDER_BY_NON_PK, url, NONE);
+        assertExpectedOutput(QUERY_ORDER_BY_NON_PK);
+    }
+
+    @Test
+    public void testOrderByNonPkAddDataByNewClientReadByOldClient() throws Exception {
+        executeQueriesWithCurrentVersion(CREATE_ORDER_BY_NON_PK, url, NONE);
+        executeQueryWithClientVersion(compatibleClientVersion, QUERY_ORDER_BY_NON_PK,
+                zkQuorum);
+        assertExpectedOutput(QUERY_ORDER_BY_NON_PK);
+    }
+
+    private boolean isClientCompatibleForOrderedGroupByQuery() {
+        String[] clientVersion = compatibleClientVersion.getVersion().split("\\.");
+        int majorVersion = Integer.parseInt(clientVersion[0]);
+        int minorVersion = Integer.parseInt(clientVersion[1]);
+        int patchVersion = Integer.parseInt(clientVersion[2]);
+        if (majorVersion > 5) {
+            return true;
+        }
+        if (majorVersion < 5) {
+            return false;
+        }
+        if (minorVersion > 1) {
+            return true;
+        }
+        if (minorVersion < 1) {
+            return false;
+        }
+        return patchVersion >= 3;
+    }
+
 }
