@@ -25,8 +25,8 @@ import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.util.VersionInfo;
-import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
-import org.apache.phoenix.coprocessor.MetaDataProtocol;
+import org.apache.phoenix.coprocessorclient.BaseScannerRegionObserverConstants;
+import org.apache.phoenix.coprocessorclient.MetaDataProtocol;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.util.PropertiesUtil;
@@ -73,6 +73,14 @@ public final class BackwardCompatibilityTestUtil {
     public static final String CREATE_ADD = "create_add";
     public static final String CREATE_TMP_TABLE = "create_tmp_table";
     public static final String CREATE_DIVERGED_VIEW = "create_diverged_view";
+    public static final String UNORDERED_GROUP_BY = "unorder_groupby";
+    public static final String ORDERED_GROUP_BY = "ordered_groupby";
+    public static final String ORDER_BY_NON_PK = "orderby_nonpk";
+    public static final String OFFSET = "offset";
+    public static final String CREATE_UNORDERED_GROUP_BY = "create_" + UNORDERED_GROUP_BY;
+    public static final String CREATE_ORDERED_GROUP_BY = "create_" + ORDERED_GROUP_BY;
+    public static final String CREATE_ORDER_BY_NON_PK = "create_" + ORDER_BY_NON_PK;
+    public static final String CREATE_OFFSET = "create_" + OFFSET;
     public static final String ADD_DATA = "add_data";
     public static final String ADD_DELETE = "add_delete";
     public static final String ADD_VIEW_INDEX = "add_view_index";
@@ -80,6 +88,10 @@ public final class BackwardCompatibilityTestUtil {
     public static final String DELETE_FOR_SPLITABLE_SYSCAT = "delete_for_splitable_syscat";
     public static final String VIEW_INDEX = "view_index";
     public static final String SELECT_AND_DROP_TABLE = "select_and_drop_table";
+    public static final String QUERY_UNORDERED_GROUP_BY = QUERY_PREFIX + UNORDERED_GROUP_BY;
+    public static final String QUERY_ORDERED_GROUP_BY = QUERY_PREFIX + ORDERED_GROUP_BY;
+    public static final String QUERY_OFFSET = QUERY_PREFIX + OFFSET;
+    public static final String QUERY_ORDER_BY_NON_PK = QUERY_PREFIX + ORDER_BY_NON_PK;
     public static final String QUERY_CREATE_ADD = QUERY_PREFIX + CREATE_ADD;
     public static final String QUERY_ADD_DATA = QUERY_PREFIX + ADD_DATA;
     public static final String QUERY_ADD_DELETE = QUERY_PREFIX + ADD_DELETE;
@@ -103,7 +115,7 @@ public final class BackwardCompatibilityTestUtil {
     private BackwardCompatibilityTestUtil() {
     }
 
-    public static List<String> computeClientVersions() throws Exception {
+    public static List<MavenCoordinates> computeClientVersions() throws Exception {
         String hbaseVersion = VersionInfo.getVersion();
         Pattern p = Pattern.compile("\\d+\\.\\d+");
         Matcher m = p.matcher(hbaseVersion);
@@ -111,7 +123,7 @@ public final class BackwardCompatibilityTestUtil {
         if (m.find()) {
             hbaseProfile = m.group();
         }
-        List<String> clientVersions = Lists.newArrayList();
+        List<MavenCoordinates> clientVersions = Lists.newArrayList();
         ObjectMapper mapper = new ObjectMapper();
         mapper.configure(JsonParser.Feature.ALLOW_COMMENTS, true);
         try (InputStream inputStream = BackwardCompatibilityIT.class
@@ -120,14 +132,14 @@ public final class BackwardCompatibilityTestUtil {
             JsonNode jsonNode = mapper.readTree(inputStream);
             JsonNode HBaseProfile = jsonNode.get(hbaseProfile);
             for (final JsonNode clientVersion : HBaseProfile) {
-                clientVersions.add(clientVersion.textValue() + "-HBase-" + hbaseProfile);
+                clientVersions.add(mapper.treeToValue(clientVersion, MavenCoordinates.class));
             }
         }
         return clientVersions;
     }
 
     // Executes the queries listed in the operation file with a given client version
-    public static void executeQueryWithClientVersion(String clientVersion, String operation,
+    public static void executeQueryWithClientVersion(MavenCoordinates clientVersion, String operation,
                                                      String zkQuorum) throws Exception {
         List<String> cmdParams = Lists.newArrayList();
         cmdParams.add(BASH);
@@ -136,7 +148,9 @@ public final class BackwardCompatibilityTestUtil {
         assertNotNull(fileUrl);
         cmdParams.add(new File(fileUrl.getFile()).getAbsolutePath());
         cmdParams.add(zkQuorum);
-        cmdParams.add(clientVersion);
+        cmdParams.add(clientVersion.getGroupId());
+        cmdParams.add(clientVersion.getArtifactId());
+        cmdParams.add(clientVersion.getVersion());
 
         fileUrl = BackwardCompatibilityIT.class.getClassLoader()
                 .getResource(SQL_DIR + operation + SQL_EXTENSION);
@@ -196,11 +210,11 @@ public final class BackwardCompatibilityTestUtil {
     }
 
 
-    public static void checkForPreConditions(String compatibleClientVersion, Configuration conf) throws Exception {
+    public static void checkForPreConditions(MavenCoordinates compatibleClientVersion, Configuration conf) throws Exception {
         // For the first code cut of any major version, there wouldn't be any backward compatible
         // clients. Hence the test wouldn't run and just return true when the client
         // version to be tested is same as current version
-        assumeFalse(compatibleClientVersion.contains(MetaDataProtocol.CURRENT_CLIENT_VERSION));
+        assumeFalse(compatibleClientVersion.getVersion().contains(MetaDataProtocol.CURRENT_CLIENT_VERSION));
         // Make sure that cluster is clean before test execution with no system tables
         try (org.apache.hadoop.hbase.client.Connection conn =
                      ConnectionFactory.createConnection(conf);
@@ -281,7 +295,7 @@ public final class BackwardCompatibilityTestUtil {
             // connection is set to be the phoenix version timestamp
             // (31 as of now: MIN_SYSTEM_TABLE_TIMESTAMP_4_16_0 / MIN_SYSTEM_TABLE_TIMESTAMP_5_1_0)
             // Hence, keeping value: 15
-            props.put(CompatBaseScannerRegionObserver.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY,
+            props.put(BaseScannerRegionObserverConstants.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY,
                     Integer.toString(15));
         }
 
@@ -321,4 +335,44 @@ public final class BackwardCompatibilityTestUtil {
             }
         }
     }
+
+    public static class MavenCoordinates {
+        private String groupId = "org.apache.phoenix";
+        private String artifactId;
+        private String version;
+
+        public MavenCoordinates() {
+            super();
+        }
+
+        public String getGroupId() {
+            return groupId;
+        }
+
+        public void setGroupId(String groupId) {
+            this.groupId = groupId;
+        }
+
+        public String getArtifactId() {
+            return artifactId;
+        }
+
+        public void setArtifactId(String artifactId) {
+            this.artifactId = artifactId;
+        }
+
+        public String getVersion() {
+            return version;
+        }
+
+        public void setVersion(String version) {
+            this.version = version;
+        }
+
+        @Override
+        public String toString() {
+            return groupId + ":" + artifactId + ":" + version;
+        }
+
+    }
 }
