@@ -38,19 +38,31 @@ import java.sql.DriverManager;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.sql.Statement;
 import java.util.Properties;
 
 import org.apache.phoenix.compile.ExplainPlan;
 import org.apache.phoenix.compile.ExplainPlanAttributes;
 import org.apache.phoenix.jdbc.PhoenixPreparedStatement;
+import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.QueryBuilder;
+import org.apache.phoenix.util.SchemaUtil;
+import org.apache.phoenix.util.TestUtil;
+import org.junit.Before;
 import org.junit.Test;
 
 
 public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
 
+    Properties props;
+    @Before
+    public void setup() {
+        props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+        props.setProperty(QueryServices.PHOENIX_SERVER_PAGE_SIZE_MS, Long.toString(0));
+    }
+
     @Test
     public void testMultiOrderByExpr() throws Exception {
         String tenantId = getOrganizationId();
@@ -60,7 +72,7 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
                     Lists.newArrayList("ENTITY_ID", "B_STRING"))
             .setFullTableName(tableName)
             .setOrderByClause("B_STRING, ENTITY_ID");
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             ResultSet rs = executeQuery(conn, queryBuilder);
             assertTrue (rs.next());
@@ -86,7 +98,6 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
         }
     }
 
-
     @Test
     public void testDescMultiOrderByExpr() throws Exception {
         String tenantId = getOrganizationId();
@@ -96,7 +107,6 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
                     Lists.newArrayList("ENTITY_ID", "B_STRING"))
             .setFullTableName(tableName)
             .setOrderByClause("B_STRING || ENTITY_ID DESC");
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             ResultSet rs = executeQuery(conn, queryBuilder);
             assertTrue (rs.next());
@@ -124,7 +134,6 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
 
     @Test
     public void testOrderByDifferentColumns() throws Exception {
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             conn.setAutoCommit(false);
             String tableName = generateUniqueName();
@@ -199,7 +208,6 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
 
     @Test
     public void testAggregateOrderBy() throws Exception {
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         Connection conn = DriverManager.getConnection(getUrl(), props);
         String tableName = generateUniqueName();
         String ddl = "create table " + tableName + " (ID VARCHAR NOT NULL PRIMARY KEY, VAL1 VARCHAR, VAL2 INTEGER)";
@@ -260,7 +268,6 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
 
     @Test
     public void testAggregateOptimizedOutOrderBy() throws Exception {
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         Connection conn = DriverManager.getConnection(getUrl(), props);
         String tableName = generateUniqueName();
         String ddl = "create table " + tableName + " (K1 VARCHAR NOT NULL, K2 VARCHAR NOT NULL, VAL1 VARCHAR, VAL2 INTEGER, CONSTRAINT pk PRIMARY KEY(K1,K2))";
@@ -340,7 +347,6 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
 
     @Test
     public void testNullsLastWithDesc() throws Exception {
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             String tableName=generateUniqueName();
             String sql="CREATE TABLE "+tableName+" ( "+
@@ -604,7 +610,6 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
     }
 
     private void doTestOrderByReverseOptimization(boolean salted,boolean desc1,boolean desc2,boolean desc3) throws Exception {
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             String tableName=generateUniqueName();
             String sql="CREATE TABLE "+tableName+" ( "+
@@ -710,7 +715,6 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
     }
 
     private void doTestOrderByReverseOptimizationWithNullsLast(boolean salted,boolean desc1,boolean desc2,boolean desc3) throws Exception {
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             String tableName=generateUniqueName();
             String sql="CREATE TABLE "+tableName+" ( "+
@@ -956,7 +960,6 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
 
     @Test
     public void testOrderByNullable() throws SQLException {
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             String sql = "CREATE TABLE IF NOT EXISTS us_population (state CHAR(2) NOT NULL," +
                     "city VARCHAR NOT NULL, population BIGINT CONSTRAINT my_pk PRIMARY KEY" +
@@ -996,4 +999,54 @@ public abstract class BaseOrderByIT extends ParallelStatsDisabledIT {
         }
     }
 
+    @Test
+    public void testPhoenix6999() throws Exception {
+        String tableName = "TBL_" + generateUniqueName();
+        String descTableName = "TBL_" + generateUniqueName();
+
+        String fullTableName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, tableName);
+        String fullDescTableName =
+                SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, descTableName);
+
+        try (Connection conn = DriverManager.getConnection(getUrl(), props);
+                Statement stmt = conn.createStatement()) {
+            conn.setAutoCommit(false);
+            String ddl =
+                    "CREATE TABLE " + fullTableName
+                            + "(k1 varchar primary key, v1 varchar, v2 varchar)";
+            stmt.execute(ddl);
+            ddl =
+                    "CREATE TABLE " + fullDescTableName
+                            + "(k1 varchar primary key desc, v1 varchar, v2 varchar)";
+            stmt.execute(ddl);
+            stmt.execute("upsert into " + fullTableName + " values ('a','a','a')");
+            stmt.execute("upsert into " + fullTableName + " values ('b','b','b')");
+            stmt.execute("upsert into " + fullTableName + " values ('c','c','c')");
+            stmt.execute("upsert into " + fullDescTableName + " values ('a','a','a')");
+            stmt.execute("upsert into " + fullDescTableName + " values ('b','b','b')");
+            stmt.execute("upsert into " + fullDescTableName + " values ('c','c','c')");
+            conn.commit();
+
+            String query = "SELECT  *  from " + fullTableName + " where k1='b' order by k1 asc";
+            ResultSet rs = stmt.executeQuery(query);
+            assertTrue(rs.next());
+            assertEquals("b", rs.getString(1));
+
+            query = "SELECT  *  from " + fullTableName + " where k1='b' order by k1 desc";
+            rs = stmt.executeQuery(query);
+            assertTrue(rs.next());
+            assertEquals("b", rs.getString(1));
+
+            query = "SELECT  *  from " + fullDescTableName + " where k1='b' order by k1 asc";
+            rs = stmt.executeQuery(query);
+            assertTrue(rs.next());
+            assertEquals("b", rs.getString(1));
+
+            query = "SELECT  *  from " + fullDescTableName + " where k1='b' order by k1 desc";
+            rs = stmt.executeQuery(query);
+            assertTrue(rs.next());
+            assertEquals("b", rs.getString(1));
+        }
+    }
+
 }
\ No newline at end of file
