@@ -28,8 +28,10 @@ import java.util.ArrayList;
 
 import org.junit.Assert;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 
 
+@Category(ParallelStatsDisabledTest.class)
 public class FirstValuesFunctionIT extends ParallelStatsDisabledIT {
 
     //@Test
