@@ -35,6 +35,7 @@ import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableKey;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.SchemaUtil;
+import org.junit.Ignore;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
@@ -149,43 +150,4 @@ public class ImmutableTablePropertiesIT extends ParallelStatsDisabledIT {
             }
         } 
     }
-    
-    @Test
-    public void testAlterImmutableStorageSchemeProp() throws Exception {
-        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
-        String immutableDataTableFullName1 = SchemaUtil.getTableName("", generateUniqueName());
-        String immutableDataTableFullName2 = SchemaUtil.getTableName("", generateUniqueName());
-        try (Connection conn = DriverManager.getConnection(getUrl(), props);) {
-            Statement stmt = conn.createStatement();
-            // create an immutable table with  ONE_CELL_PER_COLUMN storage scheme
-            String ddl = "CREATE IMMUTABLE TABLE  " + immutableDataTableFullName1 +
-                    "  (a_string varchar not null, col1 integer" +
-                    "  CONSTRAINT pk PRIMARY KEY (a_string)) COLUMN_ENCODED_BYTES=0, IMMUTABLE_STORAGE_SCHEME="
-                    + PTable.ImmutableStorageScheme.ONE_CELL_PER_COLUMN;
-            stmt.execute(ddl);
-            // create an immutable table with  SINGLE_CELL_ARRAY_WITH_OFFSETS storage scheme
-            ddl = "CREATE IMMUTABLE TABLE  " + immutableDataTableFullName2 +
-                    "  (a_string varchar not null, col1 integer" +
-                    "  CONSTRAINT pk PRIMARY KEY (a_string)) COLUMN_ENCODED_BYTES=4, IMMUTABLE_STORAGE_SCHEME="
-                    + PTable.ImmutableStorageScheme.SINGLE_CELL_ARRAY_WITH_OFFSETS;
-            stmt.execute(ddl);
-            
-            // changing the storage scheme from/to ONCE_CELL_PER_COLUMN should fail
-            try {
-                stmt.execute("ALTER TABLE " + immutableDataTableFullName1 + " SET IMMUTABLE_STORAGE_SCHEME=" + PTable.ImmutableStorageScheme.SINGLE_CELL_ARRAY_WITH_OFFSETS);
-                fail();
-            }
-            catch (SQLException e) {
-                assertEquals(SQLExceptionCode.INVALID_IMMUTABLE_STORAGE_SCHEME_CHANGE.getErrorCode(), e.getErrorCode());
-            }
-            try {
-                stmt.execute("ALTER TABLE " + immutableDataTableFullName2 + " SET IMMUTABLE_STORAGE_SCHEME=" + PTable.ImmutableStorageScheme.ONE_CELL_PER_COLUMN);
-                fail();
-            }
-            catch (SQLException e) {
-                assertEquals(SQLExceptionCode.INVALID_IMMUTABLE_STORAGE_SCHEME_CHANGE.getErrorCode(), e.getErrorCode());
-            }
-        } 
-    }
-    
 }
