@@ -19,6 +19,7 @@ package org.apache.phoenix.end2end;
 
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessor;
 import org.apache.hadoop.hbase.coprocessor.RegionObserver;
+import org.apache.phoenix.coprocessorclient.BaseScannerRegionObserverConstants;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
@@ -44,8 +45,7 @@ import org.apache.hadoop.hbase.regionserver.RegionScanner;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.hadoop.mapreduce.Counters;
-import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
-import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
+import org.apache.phoenix.coprocessor.BaseScannerRegionObserver;
 import org.apache.phoenix.coprocessor.IndexRebuildRegionScanner;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.mapreduce.index.IndexTool;
@@ -89,6 +89,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.Properties;
+import java.util.concurrent.Future;
+import java.util.concurrent.TimeUnit;
 
 import static org.apache.phoenix.mapreduce.PhoenixJobCounters.INPUT_RECORDS;
 import static org.apache.phoenix.mapreduce.index.IndexVerificationResultRepository.INDEX_TOOL_RUN_STATUS_BYTES;
@@ -171,7 +173,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
         serverProps.put(QueryServices.EXTRA_JDBC_ARGUMENTS_ATTRIB,
                 QueryServicesOptions.DEFAULT_EXTRA_JDBC_ARGUMENTS);
         serverProps.put(QueryServices.INDEX_REBUILD_PAGE_SIZE_IN_ROWS, Long.toString(8));
-        serverProps.put(CompatBaseScannerRegionObserver.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY,
+        serverProps.put(BaseScannerRegionObserverConstants.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY,
             Long.toString(MAX_LOOKBACK_AGE));
         serverProps.put(QueryServices.TASK_HANDLING_INTERVAL_MS_ATTRIB,
             Long.toString(Long.MAX_VALUE));
@@ -284,7 +286,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
                             indexTableName, dataTableFullName));
             IndexTool indexTool = IndexToolIT.runIndexTool(useSnapshot, schemaName, dataTableName, indexTableName, null, 0,
                     IndexTool.IndexVerifyType.ONLY);
-            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+            if (BaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
                 Cell cell =
                         IndexToolIT.getErrorMessageFromIndexToolOutputTable(conn, dataTableFullName,
                                 indexTableFullName);
@@ -311,15 +313,8 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
                 admin.getDescriptor(indexTable).getColumnFamilies()[0];
             ColumnFamilyDescriptor newDesc =
                 ColumnFamilyDescriptorBuilder.newBuilder(desc).setTimeToLive(1).build();
-            admin.modifyColumnFamily(indexTable, newDesc);
-            Thread.sleep(1000);
-            Pair<Integer, Integer> status = admin.getAlterStatus(indexTable);
-            int retry = 0;
-            while (retry < 20 && status.getFirst() != 0) {
-                Thread.sleep(2000);
-                status = admin.getAlterStatus(indexTable);
-            }
-            assertEquals(0, (int) status.getFirst());
+            Future<Void> modifyColumnFams = admin.modifyColumnFamilyAsync(indexTable, newDesc);
+            modifyColumnFams.get(41000, TimeUnit.MILLISECONDS);
 
             TableName indexToolOutputTable = TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME_BYTES);
             admin.disableTable(indexToolOutputTable);
@@ -429,7 +424,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_VALID_INDEX_ROW_COUNT).getValue());
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_EXPIRED_INDEX_ROW_COUNT).getValue());
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
-            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+            if (BaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
                 assertEquals(NROWS, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
                 assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
             } else {
@@ -602,7 +597,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
             IndexRebuildRegionScanner.setIgnoreIndexRebuildForTesting(true);
             conn.createStatement().execute(String.format(
                     "CREATE INDEX %s ON %s (NAME) INCLUDE (ZIP) ASYNC " + this.indexDDLOptions, indexTableName, viewFullName));
-            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+            if (BaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
                 // Run the index MR job and verify that the index table rebuild fails
                 IndexToolIT.runIndexTool(useSnapshot, schemaName, viewName, indexTableName,
                         null, -1, IndexTool.IndexVerifyType.AFTER);
@@ -624,6 +619,47 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
         }
     }
 
+    @Test
+    public void testIndexToolFailedMapperNotRecordToResultTable() throws Exception {
+        Assume.assumeTrue(mutable && singleCell);
+        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+        try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
+            String schemaName = generateUniqueName();
+            String dataTableName = generateUniqueName();
+            String dataTableFullName = SchemaUtil.getTableName(schemaName, dataTableName);
+            String indexTableName = generateUniqueName();
+            String indexTableFullName = SchemaUtil.getTableName(schemaName, indexTableName);
+            conn.createStatement().execute("CREATE TABLE " + dataTableFullName
+                    + " (ID INTEGER NOT NULL PRIMARY KEY, NAME VARCHAR, ZIP INTEGER) "
+                    + tableDDLOptions);
+            conn.commit();
+            // Insert a row
+            conn.createStatement().execute("upsert into " + dataTableFullName + " values (1, 'Phoenix', 12345)");
+            conn.commit();
+            // Configure IndexRegionObserver to fail the first write phase. This should not
+            // lead to any change on index and thus the index verify during index rebuild should fail
+            IndexRebuildRegionScanner.setThrowExceptionForRebuild(true);
+            conn.createStatement().execute(String.format(
+                    "CREATE INDEX %s ON %s (NAME) INCLUDE (ZIP) ASYNC " + this.indexDDLOptions, indexTableName, dataTableFullName));
+            // Run the index MR job and verify that the index table rebuild fails
+            IndexTool it = IndexToolIT.runIndexTool(useSnapshot, schemaName, dataTableName, indexTableName,
+                    null, -1, IndexTool.IndexVerifyType.BEFORE);
+            Assert.assertEquals(PIndexState.BUILDING, TestUtil.getIndexState(conn, indexTableFullName));
+
+            // Now there is no exception, so the second partial build should retry
+            Long scn = it.getJob().getConfiguration().getLong(CURRENT_SCN_VALUE, 1L);
+            IndexRebuildRegionScanner.setThrowExceptionForRebuild(false);
+            it = IndexToolIT.runIndexTool(useSnapshot, schemaName, dataTableName, indexTableName,
+                    null, 0, IndexTool.IndexVerifyType.BEFORE,"-rv", Long.toString(scn));
+            Assert.assertEquals(PIndexState.ACTIVE, TestUtil.getIndexState(conn, indexTableFullName));
+            ResultSet rs =
+                    conn.createStatement()
+                            .executeQuery("SELECT COUNT(*) FROM " + indexTableFullName);
+            rs.next();
+            assertEquals(1, rs.getInt(1));
+        }
+    }
+
     @Test
     public void testIndexToolOnlyVerifyOption() throws Exception {
         String schemaName = generateUniqueName();
@@ -645,7 +681,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
             // called PHOENIX_INDEX_TOOL
             IndexToolIT.runIndexTool(useSnapshot, schemaName, dataTableName, indexTableName,
                     null, 0, IndexTool.IndexVerifyType.ONLY);
-            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+            if (BaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
                 Cell cell = IndexToolIT.getErrorMessageFromIndexToolOutputTable(conn, dataTableFullName, indexTableFullName);
                 try {
                     String expectedErrorMsg = IndexRebuildRegionScanner.ERROR_MESSAGE_MISSING_INDEX_ROW;
@@ -672,7 +708,6 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
 
     @Test
     public void testIndexToolForIncrementalRebuild() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         String schemaName = generateUniqueName();
         String dataTableName = generateUniqueName();
         String dataTableFullName = SchemaUtil.getTableName(schemaName, dataTableName);
@@ -739,7 +774,6 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
 
     @Test
     public void testIndexToolForIncrementalVerify() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         ManualEnvironmentEdge customEdge = new ManualEnvironmentEdge();
         String schemaName = generateUniqueName();
         String dataTableName = generateUniqueName();
@@ -869,7 +903,6 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
 
     @Test
     public void testIndexToolForIncrementalVerify_viewIndex() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         ManualEnvironmentEdge customeEdge = new ManualEnvironmentEdge();
         String schemaName = generateUniqueName();
         String dataTableName = generateUniqueName();
@@ -1039,7 +1072,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
             truncateIndexAndIndexToolTables(indexTableFullName);
 
             boolean MaxLookbackEnabled =
-                    CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration());
+                    BaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration());
             //now check that disabling logging AFTER leaves only the BEFORE logs on a BOTH run
             assertDisableLogging(conn, MaxLookbackEnabled ? 2 : 0, IndexTool.IndexVerifyType.BOTH,
                 IndexTool.IndexDisableLoggingType.AFTER,
@@ -1071,7 +1104,6 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
 
     @Test
     public void testEnableOutputLoggingForMaxLookback() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isMaxLookbackTimeSupported());
         //by default we don't log invalid or missing rows past max lookback age to the
         // PHOENIX_INDEX_TOOL table. Verify that we can flip that logging on from the client-side
         // using a system property (such as from the command line) and have it log rows on the
@@ -1178,7 +1210,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_VALID_INDEX_ROW_COUNT).getValue());
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_EXPIRED_INDEX_ROW_COUNT).getValue());
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
-            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+            if (BaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
                 assertEquals(NROWS, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
                 assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
             } else {
@@ -1237,7 +1269,6 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
 
     @Test
     public void testIncrementalRebuildWithPageSize() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         String schemaName = generateUniqueName();
         String dataTableName = generateUniqueName();
         String fullDataTableName = SchemaUtil.getTableName(schemaName, dataTableName);
@@ -1293,7 +1324,6 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
 
     @Test
     public void testUpdatablePKFilterViewIndexRebuild() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         if (!mutable) {
             return;
         }
@@ -1372,7 +1402,6 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseTest {
 
     @Test
     public void testUpdatableNonPkFilterViewIndexRebuild() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         if (!mutable) {
             return;
         }
