@@ -20,8 +20,10 @@ package org.apache.phoenix.end2end;
 import java.util.Arrays;
 import java.util.Collection;
 
+import org.junit.experimental.categories.Category;
 import org.junit.runners.Parameterized.Parameters;
 
+@Category(ParallelStatsDisabledTest.class)
 public class SetPropertyOnNonEncodedTableIT extends SetPropertyIT {
     public SetPropertyOnNonEncodedTableIT(boolean columnEncoded) {
         super(columnEncoded);
