@@ -41,7 +41,7 @@ import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.util.Bytes;
-import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
+import org.apache.phoenix.coprocessorclient.BaseScannerRegionObserverConstants;
 import org.apache.phoenix.expression.KeyValueColumnExpression;
 import org.apache.phoenix.expression.SingleCellColumnExpression;
 import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
@@ -91,7 +91,7 @@ public class StoreNullsIT extends ParallelStatsDisabledIT {
     @BeforeClass
     public static synchronized void doSetup() throws Exception {
         Map<String, String> props = Maps.newHashMapWithExpectedSize(1);
-        props.put(CompatBaseScannerRegionObserver.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(0));
+        props.put(BaseScannerRegionObserverConstants.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(0));
         setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
     }
     
@@ -250,9 +250,7 @@ public class StoreNullsIT extends ParallelStatsDisabledIT {
     
             stmt.executeUpdate("DELETE FROM " + dataTableName + " WHERE id = 1");
             Thread.sleep(10L);
-    
             TestUtil.doMajorCompaction(conn, dataTableName);
-    
             Properties historicalProps = new Properties();
             historicalProps.setProperty(PhoenixRuntime.CURRENT_SCN_ATTRIB,
                     Long.toString(afterFirstInsert));
