@@ -37,13 +37,14 @@ import org.apache.phoenix.util.ByteUtil;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.TestUtil;
 import org.junit.Test;
-
+import org.junit.experimental.categories.Category;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * Tests for the LPAD built-in function.
  */
 
+@Category(ParallelStatsDisabledTest.class)
 public class StringIT extends ParallelStatsDisabledIT {
     
     /**
