@@ -30,7 +30,9 @@ import org.apache.phoenix.schema.types.PVarchar;
 import org.apache.phoenix.schema.types.PhoenixArray;
 import org.junit.Before;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 
+@Category(ParallelStatsDisabledTest.class)
 public class StringToArrayFunctionIT extends ParallelStatsDisabledIT {
 
     private String tableName;
