@@ -25,8 +25,9 @@ import java.sql.DriverManager;
 import java.sql.ResultSet;
 import java.sql.Statement;
 
-import static org.hamcrest.CoreMatchers.is;
-import static org.junit.Assert.assertThat;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
 
 @Category(ParallelStatsDisabledTest.class)
 public class SumFunctionIT extends ParallelStatsDisabledIT {
@@ -46,10 +47,10 @@ public class SumFunctionIT extends ParallelStatsDisabledIT {
               "select sum(case when col1 is null then col2 else 0 end), "
                 + "sum(case when col1 is not null then col2 else 0 end) from " + tableName)) {
 
-                assertThat(rs.next(), is(true));
-                assertThat(rs.getInt(1), is(1));
-                assertThat(rs.getInt(2), is(2));
-                assertThat(rs.next(), is(false));
+                assertTrue(rs.next());
+                assertEquals(rs.getInt(1), 1);
+                assertEquals(rs.getInt(2), 2);
+                assertFalse(rs.next());
             }
         }
     }
