@@ -17,8 +17,6 @@
  */
 package org.apache.phoenix.end2end;
 
-import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
@@ -30,8 +28,6 @@ import org.apache.hadoop.hbase.wal.WALEdit;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.wal.WAL;
 import org.apache.hadoop.hbase.wal.WALKey;
-import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
-import org.apache.phoenix.compat.hbase.coprocessor.CompatIndexRegionObserver;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.execute.MutationState;
 import org.apache.phoenix.hbase.index.IndexRegionObserver;
@@ -41,13 +37,10 @@ import org.apache.phoenix.query.PhoenixTestBuilder;
 import org.apache.phoenix.query.PhoenixTestBuilder.SchemaBuilder;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.schema.PTable;
-import org.apache.phoenix.schema.PTableType;
 import org.apache.phoenix.util.MetaDataUtil;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.ReadOnlyProps;
-import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.TestUtil;
-import org.junit.Assert;
 import org.junit.Assume;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -106,25 +99,21 @@ public class WALAnnotationIT extends BaseTest {
 
     @Test
     public void testSimpleUpsertAndDelete() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
         SchemaBuilder builder = new SchemaBuilder(getUrl());
         boolean createGlobalIndex = false;
-        long ddlTimestamp = upsertAndDeleteHelper(builder, createGlobalIndex);
-        assertAnnotation(2, builder.getPhysicalTableName(false), null,
-            builder.getTableOptions().getSchemaName(),
-            builder.getDataOptions().getTableName(), PTableType.TABLE, ddlTimestamp);
+        String externalSchemaId = upsertAndDeleteHelper(builder, createGlobalIndex);
+        assertAnnotation(2, builder.getPhysicalTableName(false), externalSchemaId);
     }
 
     @Test
     public void testNoAnnotationsIfChangeDetectionDisabled() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
-        try (Connection conn = DriverManager.getConnection(getUrl())) {
+        try (PhoenixConnection conn = (PhoenixConnection) DriverManager.getConnection(getUrl())) {
             conn.setAutoCommit(true);
             SchemaBuilder builder = new SchemaBuilder(getUrl());
             SchemaBuilder.TableOptions tableOptions = getTableOptions();
             tableOptions.setChangeDetectionEnabled(false);
             builder.withTableOptions(tableOptions).build();
-            PTable table = PhoenixRuntime.getTableNoCache(conn, builder.getEntityTableName());
+            PTable table = conn.getTableNoCache(builder.getEntityTableName());
             assertFalse("Change detection is enabled when it shouldn't be!",
                 table.isChangeDetectionEnabled());
             String upsertSql = "UPSERT INTO " + builder.getEntityTableName() + " VALUES" +
@@ -132,13 +121,14 @@ public class WALAnnotationIT extends BaseTest {
             conn.createStatement().execute(upsertSql);
             List<Map<String, byte[]>> entries =
                 getEntriesForTable(TableName.valueOf(builder.getPhysicalTableName(false)));
-            assertEquals(0, entries.size());
+            assertTrue("WAL annotations should not contain EXTERNAL_SCHEMA_ID", entries.size() == 0 ||
+                    !entries.get(0).containsKey(MutationState.MutationMetadataType.EXTERNAL_SCHEMA_ID.toString()));
             //now flip to TRUE so we can test disabling it
             String enableSql =
                 "ALTER TABLE " + builder.getEntityTableName() +
                     " SET " + CHANGE_DETECTION_ENABLED + "=TRUE";
             conn.createStatement().execute(enableSql);
-            table = PhoenixRuntime.getTableNoCache(conn, builder.getEntityTableName());
+            table = conn.getTableNoCache(builder.getEntityTableName());
             assertTrue("Change detection is disabled when it should be enabled!",
                 table.isChangeDetectionEnabled());
             //set to FALSE
@@ -146,20 +136,20 @@ public class WALAnnotationIT extends BaseTest {
                 "ALTER TABLE " + builder.getEntityTableName() +
                     " SET " + CHANGE_DETECTION_ENABLED + "=FALSE";
             conn.createStatement().execute(disableSql);
-            table = PhoenixRuntime.getTableNoCache(conn, builder.getEntityTableName());
+            table = conn.getTableNoCache(builder.getEntityTableName());
             assertFalse("Change detection is enabled when it should be disabled!",
                 table.isChangeDetectionEnabled());
             //now upsert again
             conn.createStatement().execute(upsertSql);
             //check that we still didn't annotate anything
             entries = getEntriesForTable(TableName.valueOf(builder.getPhysicalTableName(false)));
-            assertEquals(0, entries.size());
+            assertTrue("WAL annotations should not contain EXTERNAL_SCHEMA_ID", entries.size() == 0 ||
+                    !entries.get(0).containsKey(MutationState.MutationMetadataType.EXTERNAL_SCHEMA_ID.toString()));
         }
     }
 
     @Test
     public void testCantSetChangeDetectionOnIndex() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
         try (Connection conn = DriverManager.getConnection(getUrl())) {
             SchemaBuilder builder = new SchemaBuilder(getUrl());
             builder.withTableDefaults().build();
@@ -180,22 +170,19 @@ public class WALAnnotationIT extends BaseTest {
 
     @Test
     public void testUpsertAndDeleteWithGlobalIndex() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
         SchemaBuilder builder = new SchemaBuilder(getUrl());
         boolean createGlobalIndex = true;
-        long ddlTimestamp = upsertAndDeleteHelper(builder, createGlobalIndex);
-        assertAnnotation(2, builder.getPhysicalTableName(false), null,
-            builder.getTableOptions().getSchemaName(),
-            builder.getDataOptions().getTableName(), PTableType.TABLE, ddlTimestamp);
+        String externalSchemaId = upsertAndDeleteHelper(builder, createGlobalIndex);
+        assertAnnotation(2, builder.getPhysicalTableName(false), externalSchemaId);
         assertAnnotation(0, builder.getPhysicalTableIndexName(false),
-            null, null, null, null, ddlTimestamp);
+            externalSchemaId);
     }
 
     // Note that local secondary indexes aren't supported because they go in the same WALEdit as the
     // "base" table data they index.
 
-    private long upsertAndDeleteHelper(SchemaBuilder builder, boolean createGlobalIndex) throws Exception {
-        try (Connection conn = getConnection()) {
+    private String upsertAndDeleteHelper(SchemaBuilder builder, boolean createGlobalIndex) throws Exception {
+        try (PhoenixConnection conn = getConnection()) {
             SchemaBuilder.TableOptions tableOptions = getTableOptions();
 
             if (createGlobalIndex) {
@@ -208,8 +195,8 @@ public class WALAnnotationIT extends BaseTest {
                 " ('a', 'b', 'c')";
             conn.createStatement().execute(upsertSql);
             conn.commit();
-            PTable table = PhoenixRuntime.getTableNoCache(conn, builder.getEntityTableName());
-            assertEquals("Change Detection Enabled is false!", true, table.isChangeDetectionEnabled());
+            PTable table = conn.getTableNoCache(builder.getEntityTableName());
+            assertTrue("Change Detection Enabled is false!", table.isChangeDetectionEnabled());
             // Deleting by entire PK gets executed as more like an UPSERT VALUES than an UPSERT
             // SELECT (i.e, it generates the Mutations and then pushes them to server, rather than
             // running a select query and deleting the mutations returned)
@@ -221,7 +208,7 @@ public class WALAnnotationIT extends BaseTest {
             // last had columns added or removed. It is NOT the timestamp of a particular mutation
             // We need it in the annotation to match up with schema object in an external schema
             // repo.
-            return table.getLastDDLTimestamp();
+            return table.getExternalSchemaId();
         }
     }
 
@@ -236,8 +223,7 @@ public class WALAnnotationIT extends BaseTest {
 
     @Test
     public void testUpsertSelectClientSide() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
-        try (Connection conn = getConnection()) {
+        try (PhoenixConnection conn = getConnection()) {
             SchemaBuilder baseBuilder = new SchemaBuilder(getUrl());
             SchemaBuilder targetBuilder = new SchemaBuilder(getUrl());
             //upsert selecting from a different table will force processing to be client-side
@@ -256,29 +242,20 @@ public class WALAnnotationIT extends BaseTest {
         }
     }
 
-    private void verifyBaseAndTargetAnnotations(Connection conn, SchemaBuilder baseBuilder,
+    private void verifyBaseAndTargetAnnotations(PhoenixConnection conn, SchemaBuilder baseBuilder,
                                                 SchemaBuilder targetBuilder,
                                                 int expectedAnnotations) throws SQLException, IOException {
-        PTable baseTable = PhoenixRuntime.getTableNoCache(conn,
-            baseBuilder.getEntityTableName());
-        assertAnnotation(expectedAnnotations, baseBuilder.getPhysicalTableName(false), null,
-            baseBuilder.getTableOptions().getSchemaName(),
-            baseBuilder.getDataOptions().getTableName(),
-            PTableType.TABLE,
-            baseTable.getLastDDLTimestamp());
-        PTable targetTable = PhoenixRuntime.getTableNoCache(conn,
-            targetBuilder.getEntityTableName());
-        assertAnnotation(expectedAnnotations, targetBuilder.getPhysicalTableName(false), null,
-            targetBuilder.getTableOptions().getSchemaName(), targetBuilder.getDataOptions().getTableName(),
-            PTableType.TABLE, targetTable.getLastDDLTimestamp());
+        PTable baseTable = conn.getTableNoCache(baseBuilder.getEntityTableName());
+        assertAnnotation(expectedAnnotations, baseBuilder.getPhysicalTableName(false), baseTable.getExternalSchemaId());
+        PTable targetTable = conn.getTableNoCache(targetBuilder.getEntityTableName());
+        assertAnnotation(expectedAnnotations, targetBuilder.getPhysicalTableName(false), targetTable.getExternalSchemaId());
     }
 
     @Test
     public void testUpsertSelectServerSide() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
         Assume.assumeFalse(isImmutable); //only mutable tables can be processed server-side
         SchemaBuilder targetBuilder = new SchemaBuilder(getUrl());
-        try (Connection conn = getConnection()) {
+        try (PhoenixConnection conn = getConnection()) {
             targetBuilder.withTableOptions(getTableOptions()).build();
             conn.createStatement().execute("UPSERT INTO " + targetBuilder.getEntityTableName() + " " +
                 "VALUES" +
@@ -289,23 +266,20 @@ public class WALAnnotationIT extends BaseTest {
             String sql = "UPSERT INTO " + targetBuilder.getEntityTableName() +
                 " (OID, KP, COL1, COL2, COL3) SELECT * FROM " + targetBuilder.getEntityTableName();
             conn.createStatement().execute(sql);
-            PTable table = PhoenixRuntime.getTableNoCache(conn, targetBuilder.getEntityTableName());
-            assertAnnotation(1, targetBuilder.getPhysicalTableName(false), null,
-                targetBuilder.getTableOptions().getSchemaName(),
-                targetBuilder.getDataOptions().getTableName(),
-                PTableType.TABLE, table.getLastDDLTimestamp());
+            PTable table = conn.getTableNoCache(targetBuilder.getEntityTableName());
+            assertAnnotation(1, targetBuilder.getPhysicalTableName(false),
+                table.getExternalSchemaId());
         }
 
     }
 
     @Test
     public void testGroupedUpsertSelect() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
         // because we're inserting to a different table than we're selecting from, this should be
         // processed client-side
         SchemaBuilder baseBuilder = new SchemaBuilder(getUrl());
         SchemaBuilder targetBuilder = new SchemaBuilder(getUrl());
-        try (Connection conn = getConnection()) {
+        try (PhoenixConnection conn = getConnection()) {
             baseBuilder.withTableOptions(getTableOptions()).build();
             targetBuilder.withTableOptions(getTableOptions()).build();
             conn.createStatement().execute("UPSERT INTO " + baseBuilder.getEntityTableName() + " VALUES" +
@@ -328,10 +302,9 @@ public class WALAnnotationIT extends BaseTest {
     }
 
     private void testRangeDeleteHelper(boolean isClientSide) throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
         SchemaBuilder builder = new SchemaBuilder(getUrl());
         builder.withTableOptions(getTableOptions()).build();
-        try (Connection conn = getConnection()) {
+        try (PhoenixConnection conn = getConnection()) {
             conn.createStatement().execute("UPSERT INTO " + builder.getEntityTableName() +
                 " VALUES ('a', 'b', '2', 'bc', '3')");
             conn.commit();
@@ -346,10 +319,8 @@ public class WALAnnotationIT extends BaseTest {
             conn.setAutoCommit(!isClientSide);
             conn.createStatement().execute(sql);
             conn.commit();
-            PTable table = PhoenixRuntime.getTableNoCache(conn, builder.getEntityTableName());
-            assertAnnotation(2, table.getPhysicalName().getString(), null,
-                table.getSchemaName().getString(),
-                table.getTableName().getString(), PTableType.TABLE, table.getLastDDLTimestamp());
+            PTable table = conn.getTableNoCache(builder.getEntityTableName());
+            assertAnnotation(2, table.getPhysicalName().getString(), table.getExternalSchemaId());
         }
 
     }
@@ -362,9 +333,8 @@ public class WALAnnotationIT extends BaseTest {
 
     @Test
     public void testGlobalViewUpsert() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
         SchemaBuilder builder = new SchemaBuilder(getUrl());
-        try (Connection conn = getConnection()) {
+        try (PhoenixConnection conn = getConnection()) {
             createGlobalViewHelper(builder, conn);
             conn.createStatement().execute("UPSERT INTO " + builder.getEntityGlobalViewName()
                 + " VALUES" + " ('a', '" + PhoenixTestBuilder.DDLDefaults.DEFAULT_KP +
@@ -375,18 +345,16 @@ public class WALAnnotationIT extends BaseTest {
                 "and ID = 'c'";
             conn.createStatement().execute(deleteSql);
             conn.commit();
-            PTable view = PhoenixRuntime.getTableNoCache(conn, builder.getEntityGlobalViewName());
-            assertAnnotation(2, view.getPhysicalName().getString(), null,
-                view.getSchemaName().getString(),
-                view.getTableName().getString(), PTableType.VIEW, view.getLastDDLTimestamp());
+            PTable view = conn.getTableNoCache(builder.getEntityGlobalViewName());
+            assertAnnotation(2, view.getPhysicalName().getString(), view.getExternalSchemaId());
         }
 
     }
 
-    private void createGlobalViewHelper(SchemaBuilder builder, Connection conn) throws Exception {
+    private void createGlobalViewHelper(SchemaBuilder builder, PhoenixConnection conn) throws Exception {
         builder.withTableOptions(getTableOptions()).
             withGlobalViewOptions(getGlobalViewOptions(builder)).build();
-        PTable view = PhoenixRuntime.getTableNoCache(conn, builder.getEntityGlobalViewName());
+        PTable view = conn.getTableNoCache(builder.getEntityGlobalViewName());
         assertTrue("View does not have change detection enabled!",
             view.isChangeDetectionEnabled());
     }
@@ -399,7 +367,6 @@ public class WALAnnotationIT extends BaseTest {
 
     @Test
     public void testTenantViewUpsert() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
         Assume.assumeTrue(isMultiTenant);
         boolean createIndex = false;
         tenantViewHelper(createIndex);
@@ -410,10 +377,10 @@ public class WALAnnotationIT extends BaseTest {
         // child tenant view. Make sure that the annotations use the tenant view name
         String tenant = generateUniqueName();
         SchemaBuilder builder = new SchemaBuilder(getUrl());
-        try (Connection conn = getConnection()) {
+        try (PhoenixConnection conn = getConnection()) {
             createGlobalViewHelper(builder, conn);
         }
-        try (Connection conn = getTenantConnection(tenant)) {
+        try (PhoenixConnection conn = (PhoenixConnection) getTenantConnection(tenant)) {
             SchemaBuilder.DataOptions dataOptions = builder.getDataOptions();
             dataOptions.setTenantId(tenant);
             if (createIndex) {
@@ -434,14 +401,12 @@ public class WALAnnotationIT extends BaseTest {
                 "' and COL1 = '2' AND ID = 'c' AND ZID = 'd'";
             conn.createStatement().execute(deleteSql);
             conn.commit();
-            PTable view = PhoenixRuntime.getTableNoCache(conn, builder.getEntityTenantViewName());
-            assertAnnotation(2, view.getPhysicalName().getString(), tenant,
-                view.getSchemaName().getString(),
-                view.getTableName().getString(), PTableType.VIEW, view.getLastDDLTimestamp());
+            PTable view = conn.getTableNoCache(builder.getEntityTenantViewName());
+            assertAnnotation(2, view.getPhysicalName().getString(), view.getExternalSchemaId());
             if (createIndex) {
                 assertAnnotation(0,
                     MetaDataUtil.getViewIndexPhysicalName(builder.getEntityTableName()),
-                    tenant, null, null, null, view.getLastDDLTimestamp());
+                    view.getExternalSchemaId());
             }
         }
 
@@ -455,11 +420,41 @@ public class WALAnnotationIT extends BaseTest {
 
     @Test
     public void testTenantViewUpsertWithIndex() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.hasPreWALAppend());
         Assume.assumeTrue(isMultiTenant);
         tenantViewHelper(true);
     }
 
+    @Test
+    public void testOnDuplicateUpsertWithIndex() throws Exception {
+        Assume.assumeFalse(this.isImmutable); // on duplicate is not supported for immutable tables
+        SchemaBuilder builder = new SchemaBuilder(getUrl());
+        try (PhoenixConnection conn = getConnection()) {
+            SchemaBuilder.TableOptions tableOptions = getTableOptions();
+            builder.withTableOptions(tableOptions).withTableIndexDefaults().build();
+            PTable table = conn.getTableNoCache(builder.getEntityTableName());
+            assertTrue("Change Detection Enabled is false!", table.isChangeDetectionEnabled());
+            Long ddlTimestamp = table.getLastDDLTimestamp();
+            String upsertSql = "UPSERT INTO " + builder.getEntityTableName() + " VALUES" +
+                " ('a', 'b', 'c', 'd')";
+            conn.createStatement().execute(upsertSql);
+            conn.commit();
+            List<String> columns = builder.getTableOptions().getTableColumns();
+            assertTrue(columns.size() >= 2);
+            String col1 = columns.get(0);
+            String col2 = columns.get(1);
+            // col1 = col1 || col1, col2 = null
+            String onDupClause = String.format("%s = %s || %s, %s = null", col1, col1, col1, col2);
+            // this will result in one Put and one Delete (because of null) mutation
+            upsertSql = "UPSERT INTO " + builder.getEntityTableName() + " VALUES" +
+                " ('a', 'b', 'c', 'd') ON DUPLICATE KEY UPDATE " + onDupClause;
+            conn.createStatement().execute(upsertSql);
+            conn.commit();
+            assertAnnotation(2, builder.getPhysicalTableName(false), table.getExternalSchemaId());
+            assertAnnotation(0, builder.getPhysicalTableIndexName(false),
+                table.getExternalSchemaId());
+        }
+    }
+
     private List<Map<String, byte[]>> getEntriesForTable(TableName tableName) throws IOException {
         AnnotatedWALObserver c = getTestCoprocessor(tableName);
         List<Map<String, byte[]>> entries = c.getWalAnnotationsByTable(tableName);
@@ -478,29 +473,16 @@ public class WALAnnotationIT extends BaseTest {
         observer.clearAnnotations();
     }
 
-    private void assertAnnotation(int numOccurrences, String physicalTableName, String tenant,
-                                  String schemaName,
-                                  String logicalTableName,
-                                  PTableType tableType, long ddlTimestamp) throws IOException {
+    private void assertAnnotation(int numOccurrences, String physicalTableName,
+        String externalSchemaId) throws IOException {
         int foundCount = 0;
         int notFoundCount = 0;
         List<Map<String, byte[]>> entries =
             getEntriesForTable(TableName.valueOf(physicalTableName));
         for (Map<String, byte[]> m : entries) {
-            byte[] tenantBytes = m.get(MutationState.MutationMetadataType.TENANT_ID.toString());
-            byte[] schemaBytes = m.get(MutationState.MutationMetadataType.SCHEMA_NAME.toString());
-            byte[] logicalTableBytes =
-                m.get(MutationState.MutationMetadataType.LOGICAL_TABLE_NAME.toString());
-            byte[] tableTypeBytes = m.get(MutationState.MutationMetadataType.TABLE_TYPE.toString());
-            byte[] timestampBytes = m.get(MutationState.MutationMetadataType.TIMESTAMP.toString());
-            assertNotNull(timestampBytes);
-            long timestamp = Bytes.toLong(timestampBytes);
-            if (Objects.equals(tenant, Bytes.toString(tenantBytes)) &&
-                Objects.equals(schemaName, Bytes.toString(schemaBytes)) &&
-                Objects.equals(logicalTableName, Bytes.toString(logicalTableBytes)) &&
-                Objects.equals(tableType.toString(), Bytes.toString(tableTypeBytes)) &&
-                Objects.equals(ddlTimestamp, timestamp)
-                && timestamp < HConstants.LATEST_TIMESTAMP) {
+            byte[] externalSchemaIdBytes = m.get(MutationState.MutationMetadataType.EXTERNAL_SCHEMA_ID.toString());
+            assertNotNull(externalSchemaIdBytes);
+            if (Objects.equals(externalSchemaId, Bytes.toString(externalSchemaIdBytes))) {
                 foundCount++;
             } else {
                 notFoundCount++;
@@ -543,7 +525,7 @@ public class WALAnnotationIT extends BaseTest {
                                  RegionInfo info, WALKey logKey, WALEdit logEdit) throws IOException {
             TableName tableName = logKey.getTableName();
             Map<String, byte[]> annotationMap =
-                CompatIndexRegionObserver.getAttributeValuesFromWALKey(logKey);
+                IndexRegionObserver.getAttributeValuesFromWALKey(logKey);
             if (annotationMap.size() > 0) {
                 if (!walAnnotations.containsKey(tableName)) {
                     walAnnotations.put(tableName, new ArrayList<Map<String, byte[]>>());
