@@ -21,24 +21,23 @@ import java.util.Arrays;
 import java.util.Collection;
 
 import org.apache.phoenix.end2end.ParallelStatsDisabledTest;
-import org.apache.phoenix.util.TestUtil;
 import org.junit.experimental.categories.Category;
 import org.junit.runners.Parameterized.Parameters;
 
 @Category(ParallelStatsDisabledTest.class)
 public class GlobalMutableTxIndexIT extends BaseIndexIT {
 
-    public GlobalMutableTxIndexIT(boolean localIndex, boolean mutable, String transactionProvider, boolean columnEncoded) {
-        super(localIndex, mutable, transactionProvider, columnEncoded);
+    public GlobalMutableTxIndexIT(String transactionProvider, boolean columnEncoded) {
+        super(false, false, true, transactionProvider, columnEncoded);
     }
 
-    @Parameters(name="GlobalMutableTxIndexIT_localIndex={0},mutable={1},transactionProvider={2},columnEncoded={3}") // name is used by failsafe as file name in reports
+    // name is used by failsafe as file name in reports
+    @Parameters(name="GlobalMutableTxIndexIT_transactionProvider={0},columnEncoded={1}")
     public static synchronized Collection<Object[]> data() {
-        return TestUtil.filterTxParamData(
-                Arrays.asList(new Object[][] {
-                    { false, true, "TEPHRA", false }, { false, true, "TEPHRA", true },
-                    { false, true, "OMID", false },
-               }), 2);
+        return Arrays.asList(new Object[][] {
+            // OMID does not support local indexes or column encoding
+            { "OMID", false },
+        });
     }
 
 }
