@@ -35,7 +35,6 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.sql.Timestamp;
 import java.util.Calendar;
-import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 
@@ -61,7 +60,7 @@ import org.apache.hadoop.hbase.util.Pair;
 import org.apache.phoenix.compile.ExplainPlan;
 import org.apache.phoenix.compile.ExplainPlanAttributes;
 import org.apache.phoenix.compile.QueryPlan;
-import org.apache.phoenix.coprocessor.BaseScannerRegionObserver;
+import org.apache.phoenix.coprocessorclient.BaseScannerRegionObserverConstants;
 import org.apache.phoenix.end2end.ExplainPlanWithStatsEnabledIT.Estimate;
 import org.apache.phoenix.hbase.index.IndexRegionSplitPolicy;
 import org.apache.phoenix.jdbc.PhoenixConnection;
@@ -386,6 +385,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
     public void testUseUncoveredLocalIndexWithPrefix() throws Exception {
         String tableName = schemaName + "." + generateUniqueName();
         String indexName = "IDX_" + generateUniqueName();
+        String fullIndexName = SchemaUtil.getTableName(schemaName, indexName);
         TableName physicalTableName = SchemaUtil.getPhysicalTableName(tableName.getBytes(), isNamespaceMapped);
         String indexPhysicalTableName = physicalTableName.getNameAsString();
 
@@ -422,7 +422,8 @@ public class LocalIndexIT extends BaseLocalIndexIT {
                 explainPlanAttributes.getIteratorTypeAndScanSize());
         assertEquals("RANGE SCAN ",
                 explainPlanAttributes.getExplainScanType());
-        assertEquals(indexPhysicalTableName, explainPlanAttributes.getTableName());
+        assertEquals( fullIndexName+ "(" + indexPhysicalTableName + ")",
+                explainPlanAttributes.getTableName());
         assertEquals(" [1,3,4]", explainPlanAttributes.getKeyRanges());
         assertEquals("SERVER FILTER BY FIRST KEY ONLY",
                 explainPlanAttributes.getServerWhereFilter());
@@ -454,7 +455,8 @@ public class LocalIndexIT extends BaseLocalIndexIT {
                 explainPlanAttributes.getIteratorTypeAndScanSize());
         assertEquals("RANGE SCAN ",
                 explainPlanAttributes.getExplainScanType());
-        assertEquals(physicalTableName.toString(), explainPlanAttributes.getTableName());
+        assertEquals(fullIndexName+ "(" + indexPhysicalTableName + ")",
+                explainPlanAttributes.getTableName());
         assertEquals(" [1,3,4,3]", explainPlanAttributes.getKeyRanges());
         assertEquals("[0.V3]", explainPlanAttributes.getServerMergeColumns().toString());
         assertEquals("SERVER FILTER BY FIRST KEY ONLY AND \"V3\" = 1",
@@ -467,6 +469,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
     public void testUseUncoveredLocalIndexWithSplitPrefix() throws Exception {
         String tableName = schemaName + "." + generateUniqueName();
         String indexName = "IDX_" + generateUniqueName();
+        String fullIndexName = SchemaUtil.getTableName(schemaName, indexName);
         TableName physicalTableName = SchemaUtil.getPhysicalTableName(tableName.getBytes(), isNamespaceMapped);
         String indexPhysicalTableName = physicalTableName.getNameAsString();
 
@@ -485,7 +488,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         ResultSet rs = conn.createStatement().executeQuery("EXPLAIN SELECT pk1, pk2, pk3, v1 FROM " + tableName + " WHERE pk1 = 2 AND pk3 = 3");
         assertEquals(
             "CLIENT PARALLEL 16-WAY RANGE SCAN OVER "
-                    + indexPhysicalTableName + " [1,2,3]\n"
+                    + fullIndexName +  "(" + indexPhysicalTableName + ") [1,2,3]\n"
                     + "    SERVER MERGE [0.V1]\n"
                     + "    SERVER FILTER BY FIRST KEY ONLY\n"
                     + "CLIENT MERGE SORT",
@@ -497,6 +500,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
     public void testUseUncoveredLocalIndex() throws Exception {
         String tableName = schemaName + "." + generateUniqueName();
         String indexName = "IDX_" + generateUniqueName();
+        String fullIndexName = SchemaUtil.getTableName(schemaName, indexName);
         TableName physicalTableName = SchemaUtil.getPhysicalTableName(tableName.getBytes(), isNamespaceMapped);
         String indexPhysicalTableName = physicalTableName.getNameAsString();
 
@@ -514,7 +518,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         ResultSet rs = conn.createStatement().executeQuery("EXPLAIN SELECT COUNT(*) FROM " + tableName);
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
-                    + indexPhysicalTableName + " [1]\n"
+                    + fullIndexName + "(" + indexPhysicalTableName + ") [1]\n"
                             + "    SERVER FILTER BY FIRST KEY ONLY\n"
                             + "    SERVER AGGREGATE INTO SINGLE ROW",
                     QueryUtil.getExplainPlan(rs));
@@ -531,7 +535,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         rs = conn.createStatement().executeQuery("EXPLAIN SELECT * FROM " + tableName + " ORDER BY v2");
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
-                    + indexPhysicalTableName + " [1]\n"
+                    + fullIndexName + "(" + indexPhysicalTableName + ") [1]\n"
                             + "    SERVER MERGE [0.V1]\n"
                             + "    SERVER FILTER BY FIRST KEY ONLY\n"
                             + "CLIENT MERGE SORT",
@@ -552,7 +556,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         rs = conn.createStatement().executeQuery("EXPLAIN SELECT * FROM " + tableName + " WHERE v2 = 2 ORDER BY v3");
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
-                    + indexPhysicalTableName + " [1,2]\n"
+                    + fullIndexName + "(" + indexPhysicalTableName + ") [1,2]\n"
                             + "    SERVER MERGE [0.V1]\n"
                             + "    SERVER FILTER BY FIRST KEY ONLY\n"
                             + "CLIENT MERGE SORT",
@@ -581,7 +585,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         rs = conn.createStatement().executeQuery("EXPLAIN SELECT * FROM " + tableName + " WHERE v2 = 2");
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
-                    + indexPhysicalTableName + " [1,2]\n"
+                    + fullIndexName + "(" + indexPhysicalTableName + ") [1,2]\n"
                             + "    SERVER MERGE [0.V1]\n"
                             + "    SERVER FILTER BY FIRST KEY ONLY\n"
                             + "CLIENT MERGE SORT",
@@ -592,7 +596,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         rs = conn.createStatement().executeQuery("EXPLAIN SELECT * FROM " + tableName + " WHERE v2 = 2 AND v4 = 4");
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
-                    + indexPhysicalTableName + " [1,2]\n"
+                    + fullIndexName + "(" + indexPhysicalTableName + ") [1,2]\n"
                             + "    SERVER MERGE [0.V1]\n"
                             + "    SERVER FILTER BY FIRST KEY ONLY AND TO_INTEGER(\"V4\") = 4\n"
                             + "CLIENT MERGE SORT",
@@ -603,7 +607,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         rs = conn.createStatement().executeQuery("EXPLAIN SELECT * FROM " + tableName + " WHERE v2 = 2 AND v1 = 3");
         assertEquals(
             "CLIENT PARALLEL 1-WAY RANGE SCAN OVER "
-                    + indexPhysicalTableName + " [1,2]\n"
+                    + fullIndexName + "(" + indexPhysicalTableName + ") [1,2]\n"
                     + "    SERVER MERGE [0.V1]\n"
                     + "    SERVER FILTER BY FIRST KEY ONLY AND \"V1\" = 3.0\n"
                     + "CLIENT MERGE SORT",
@@ -777,8 +781,8 @@ public class LocalIndexIT extends BaseLocalIndexIT {
         for (int i = 0; i < startKeys.length; i++) {
             Scan s = new Scan();
             s.addFamily(QueryConstants.DEFAULT_LOCAL_INDEX_COLUMN_FAMILY_BYTES);
-            s.setStartRow(startKeys[i]);
-            s.setStopRow(endKeys[i]);
+            s.withStartRow(startKeys[i]);
+            s.withStopRow(endKeys[i]);
             ResultScanner scanner = indexTable.getScanner(s);
             int count = 0;
             for(Result r:scanner){
@@ -794,6 +798,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
     public void testLocalIndexUsedForUncoveredOrderBy() throws Exception {
         String tableName = schemaName + "." + generateUniqueName();
         String indexName = "IDX_" + generateUniqueName();
+        String fullIndexName = SchemaUtil.getTableName(schemaName, indexName);
         TableName physicalTableName = SchemaUtil.getPhysicalTableName(tableName.getBytes(), isNamespaceMapped);
         String indexPhysicalTableName = physicalTableName.getNameAsString();
 
@@ -810,11 +815,11 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             ResultSet rs = conn1.createStatement().executeQuery("EXPLAIN "+ query);
 
             Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
-            int numRegions = admin.getTableRegions(physicalTableName).size();
+            int numRegions = admin.getRegions(physicalTableName).size();
 
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
-                        + indexPhysicalTableName + " [1]\n"
+                        + fullIndexName + "(" + indexPhysicalTableName + ") [1]\n"
                                 + "    SERVER MERGE [0.K3]\n"
                                 + "    SERVER FILTER BY FIRST KEY ONLY\n"
                                 + "CLIENT MERGE SORT",
@@ -837,7 +842,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             rs = conn1.createStatement().executeQuery("EXPLAIN "+ query);
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY REVERSE RANGE SCAN OVER "
-                        + indexPhysicalTableName + " [1]\n"
+                        + fullIndexName + "(" + indexPhysicalTableName + ") [1]\n"
                                 + "    SERVER MERGE [0.K3]\n"
                                 + "    SERVER FILTER BY FIRST KEY ONLY\n"
                                 + "CLIENT MERGE SORT",
@@ -863,6 +868,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
     public void testLocalIndexReverseScanShouldReturnAllRows() throws Exception {
         String tableName = schemaName + "." + generateUniqueName();
         String indexName = "IDX_" + generateUniqueName();
+        String fullIndexName = SchemaUtil.getTableName(schemaName, indexName);
         TableName physicalTableName = SchemaUtil.getPhysicalTableName(tableName.getBytes(), isNamespaceMapped);
         String indexPhysicalTableName = physicalTableName.getNameAsString();
 
@@ -879,11 +885,11 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             ResultSet rs = conn1.createStatement().executeQuery("EXPLAIN "+ query);
 
             Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
-            int numRegions = admin.getTableRegions(physicalTableName).size();
+            int numRegions = admin.getRegions(physicalTableName).size();
 
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY REVERSE RANGE SCAN OVER "
-                        + indexPhysicalTableName + " [1]\n"
+                        + fullIndexName + "(" + indexPhysicalTableName + ") [1]\n"
                                 + "    SERVER FILTER BY FIRST KEY ONLY\n"
                                 + "CLIENT MERGE SORT",
                         QueryUtil.getExplainPlan(rs));
@@ -908,6 +914,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
     public void testLocalIndexScanJoinColumnsFromDataTable() throws Exception {
         String tableName = schemaName + "." + generateUniqueName();
         String indexName = "IDX_" + generateUniqueName();
+        String fullIndexName = SchemaUtil.getTableName(schemaName, indexName);
         String indexTableName = schemaName + "." + indexName;
         TableName physicalTableName = SchemaUtil.getPhysicalTableName(tableName.getBytes(), isNamespaceMapped);
         String indexPhysicalTableName = physicalTableName.getNameAsString();
@@ -926,14 +933,14 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             assertTrue(rs.next());
             
             Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
-            int numRegions = admin.getTableRegions(physicalTableName).size();
+            int numRegions = admin.getRegions(physicalTableName).size();
             
             String query = "SELECT t_id, k1, k2, k3, V1 FROM " + tableName +" where v1='a'";
             rs = conn1.createStatement().executeQuery("EXPLAIN "+ query);
             
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
-                        + indexPhysicalTableName + " [1,'a']\n"
+                        + fullIndexName + "(" + indexPhysicalTableName + ") [1,'a']\n"
                                 + "    SERVER MERGE [0.K3]\n"
                                 + "    SERVER FILTER BY FIRST KEY ONLY\n"
                                 + "CLIENT MERGE SORT",
@@ -957,7 +964,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
-                        + indexPhysicalTableName +" [1,*] - [1,'z']\n"
+                        + fullIndexName + "(" + indexPhysicalTableName + ") [1,*] - [1,'z']\n"
                         + "    SERVER MERGE [0.K3]\n"
                         + "    SERVER FILTER BY FIRST KEY ONLY\n"
                          + "CLIENT MERGE SORT",
@@ -994,7 +1001,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
-                        + indexPhysicalTableName +" [1,*] - [1,'z']\n"
+                        + fullIndexName + "(" + indexPhysicalTableName + ") [1,*] - [1,'z']\n"
                         + "    SERVER MERGE [0.K3]\n"
                         + "    SERVER FILTER BY FIRST KEY ONLY\n"
                         + "    SERVER AGGREGATE INTO DISTINCT ROWS BY [\"V1\", \"T_ID\", \"K3\"]\nCLIENT MERGE SORT",
@@ -1023,7 +1030,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             rs = conn1.createStatement().executeQuery("EXPLAIN " + query);
             assertEquals(
                 "CLIENT PARALLEL " + numRegions + "-WAY RANGE SCAN OVER "
-                        + indexPhysicalTableName +" [1,*] - [1,'z']\n"
+                        + fullIndexName + "(" + indexPhysicalTableName + ") [1,*] - [1,'z']\n"
                         + "    SERVER MERGE [0.K3]\n"
                         + "    SERVER FILTER BY FIRST KEY ONLY\n"
                         + "    SERVER AGGREGATE INTO ORDERED DISTINCT ROWS BY [\"V1\"]\nCLIENT MERGE SORT",
@@ -1033,7 +1040,7 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             rs = stmt.executeQuery(query);
             QueryPlan plan = stmt.getQueryPlan();
             assertEquals(indexTableName, plan.getContext().getCurrentTable().getTable().getName().getString());
-            assertEquals(BaseScannerRegionObserver.KEY_ORDERED_GROUP_BY_EXPRESSIONS, plan.getGroupBy().getScanAttribName());
+            assertEquals(BaseScannerRegionObserverConstants.KEY_ORDERED_GROUP_BY_EXPRESSIONS, plan.getGroupBy().getScanAttribName());
             assertTrue(rs.next());
             assertEquals("a", rs.getString(1));
             assertEquals(5, rs.getInt(2));
@@ -1098,8 +1105,8 @@ public class LocalIndexIT extends BaseLocalIndexIT {
             // No entry should be present in local index table after drop index.
             for (int i = 0; i < startKeys.length; i++) {
                 Scan s = new Scan();
-                s.setStartRow(startKeys[i]);
-                s.setStopRow(endKeys[i]);
+                s.withStartRow(startKeys[i]);
+                s.withStopRow(endKeys[i]);
                 ColumnFamilyDescriptor[] families = table.getDescriptor().getColumnFamilies();
                 for(ColumnFamilyDescriptor cf: families) {
                     if(cf.getNameAsString().startsWith(QueryConstants.LOCAL_INDEX_COLUMN_FAMILY_PREFIX)){
