@@ -47,35 +47,35 @@ import org.junit.runners.Parameterized.Parameters;
 @RunWith(Parameterized.class)
 public class RollbackIT extends ParallelStatsDisabledIT {
 	
-	private final boolean localIndex;
+    private final boolean localIndex;
     private final String tableDDLOptions;
 
-	public RollbackIT(boolean localIndex, boolean mutable, String transactionProvider) {
-		this.localIndex = localIndex;
+    public RollbackIT(boolean localIndex, boolean mutable, String transactionProvider) {
+        this.localIndex = localIndex;
         StringBuilder optionBuilder = new StringBuilder();
         optionBuilder.append(" TRANSACTION_PROVIDER='" + transactionProvider + "'");
         if (!mutable) {
             optionBuilder.append(",IMMUTABLE_ROWS=true");
         }
         this.tableDDLOptions = optionBuilder.toString();
-	}
-	
+    }
+
     private static Connection getConnection() throws SQLException {
         Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         props.put(QueryServices.DEFAULT_TABLE_ISTRANSACTIONAL_ATTRIB, Boolean.toString(true));
         Connection conn = DriverManager.getConnection(getUrl(), props);
         return conn;
     }
-    
-	@Parameters(name="RollbackIT_localIndex={0},mutable={1},transactionProvider={2}") // name is used by failsafe as file name in reports
+
+    // name is used by failsafe as file name in reports
+    @Parameters(name="RollbackIT_localIndex={0},mutable={1},transactionProvider={2}")
     public static synchronized Collection<Object[]> data() {
-        return TestUtil.filterTxParamData(Arrays.asList(new Object[][] {     
-                 { false, false, "TEPHRA" }, { false, true, "TEPHRA"  },
-                 { true, false, "TEPHRA"  }, { true, true, "TEPHRA"  },
-                 { false, false, "OMID" }, { false, true, "OMID"  },
-           }),2);
+      return Arrays.asList(new Object[][] {
+          // OMID does not support local indexes
+          { false, false, "OMID" }, { false, true, "OMID" },
+      });
     }
-    
+
     @Test
     public void testRollbackOfUncommittedKeyValueIndexInsert() throws Exception {
         String tableName = "TBL_" + generateUniqueName();
