@@ -34,7 +34,7 @@ import java.util.concurrent.TimeUnit;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.htrace.*;
 import org.apache.htrace.impl.ProbabilitySampler;
-import org.apache.phoenix.coprocessor.BaseScannerRegionObserver;
+import org.apache.phoenix.coprocessorclient.BaseScannerRegionObserverConstants;
 import org.apache.phoenix.end2end.ParallelStatsDisabledTest;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.trace.TraceReader.SpanInfo;
@@ -312,7 +312,7 @@ public class PhoenixTracingEndToEndIT extends BaseTracingTestIT {
             @Override
             public boolean foundTrace(TraceHolder trace) {
                 String traceInfo = trace.toString();
-                return traceInfo.contains(BaseScannerRegionObserver.SCANNER_OPENED_TRACE_INFO);
+                return traceInfo.contains(BaseScannerRegionObserverConstants.SCANNER_OPENED_TRACE_INFO);
             }
         });
         assertTrue("Didn't find the parallel scanner in the tracing", found);
