@@ -75,7 +75,6 @@ import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.StringUtil;
 import org.apache.phoenix.util.TestUtil;
-import org.apache.tephra.TxConstants;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.junit.runner.RunWith;
@@ -95,10 +94,10 @@ public class TransactionIT  extends ParallelStatsDisabledIT {
         tableDDLOptions = PhoenixDatabaseMetaData.TRANSACTION_PROVIDER + "='" + provider + "'";
     }
 
-    @Parameters(name="TransactionIT_provider={0}") // name is used by failsafe as file name in reports
+    // name is used by failsafe as file name in reports
+    @Parameters(name="TransactionIT_provider={0}")
     public static synchronized Collection<Object[]> data() {
-        return TestUtil.filterTxParamData(Arrays.asList(new Object[][] { 
-                 {"TEPHRA"},{"OMID"}}),0);
+        return Arrays.asList(new Object[][] { { "OMID" } });
     }
 
     @Test
@@ -190,13 +189,11 @@ public class TransactionIT  extends ParallelStatsDisabledIT {
         List<String> tableNames = Lists.newArrayList();
         Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
-            for (TransactionFactory.Provider provider : TransactionFactory.Provider.values()) {
-                if (provider.runTests()) {
-                    String tableName = generateUniqueName();
-                    tableNames.add(tableName);
-                    conn.createStatement().execute(
-                            "CREATE TABLE " + tableName + " (k VARCHAR NOT NULL PRIMARY KEY, v1 VARCHAR) TRANSACTIONAL=true,TRANSACTION_PROVIDER='" + provider + "'");
-                }
+            for (TransactionFactory.Provider provider : TransactionFactory.Provider.available()) {
+              String tableName = generateUniqueName();
+              tableNames.add(tableName);
+              conn.createStatement().execute(
+                  "CREATE TABLE " + tableName + " (k VARCHAR NOT NULL PRIMARY KEY, v1 VARCHAR) TRANSACTIONAL=true,TRANSACTION_PROVIDER='" + provider + "'");
             }
             if (tableNames.size() < 2) {
                 return;
@@ -230,8 +227,8 @@ public class TransactionIT  extends ParallelStatsDisabledIT {
     public void testPreventLocalIndexCreation() throws Exception {
         Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
-            for (TransactionFactory.Provider provider : TransactionFactory.Provider.values()) {
-                if (provider.runTests() && provider.getTransactionProvider().isUnsupported(PhoenixTransactionProvider.Feature.ALLOW_LOCAL_INDEX)) {
+            for (TransactionFactory.Provider provider : TransactionFactory.Provider.available()) {
+                if (provider.getTransactionProvider().isUnsupported(PhoenixTransactionProvider.Feature.ALLOW_LOCAL_INDEX)) {
                     String tableName = generateUniqueName();
                     conn.createStatement().execute(
                             "CREATE TABLE " + tableName + " (k VARCHAR NOT NULL PRIMARY KEY, v1 VARCHAR) TRANSACTIONAL=true,TRANSACTION_PROVIDER='" + provider + "'");
@@ -330,7 +327,7 @@ public class TransactionIT  extends ParallelStatsDisabledIT {
             assertEquals(txProvider, rs.getString(PhoenixDatabaseMetaData.TRANSACTION_PROVIDER));
             
             // Ensure round-trip-ability of TRANSACTION_PROVIDER
-            PTable table = PhoenixRuntime.getTableNoCache(conn, transactTableName);
+            PTable table = conn.unwrap(PhoenixConnection.class).getTableNoCache(transactTableName);
             assertEquals(txProvider, table.getTransactionProvider().name());
 
             String nonTransactTableName = generateUniqueName();
@@ -384,7 +381,7 @@ public class TransactionIT  extends ParallelStatsDisabledIT {
             if (TransactionFactory.Provider.valueOf(txProvider).getTransactionProvider().isUnsupported(Feature.ALTER_NONTX_TO_TX)) {
                 fail(txProvider + " should not allow converting a non transactional table to be transactional");
             }
-        } catch (SQLException e) { // Should fail for Omid, but not Tephra
+        } catch (SQLException e) { // Should fail for Omid
             if (!TransactionFactory.Provider.valueOf(txProvider).getTransactionProvider().isUnsupported(Feature.ALTER_NONTX_TO_TX)) {
                 throw e;
             }
@@ -548,9 +545,8 @@ public class TransactionIT  extends ParallelStatsDisabledIT {
     }
     
     private static void assertTTL(Admin admin, String tableName, int ttl) throws Exception {
-        TableDescriptor tableDesc = admin.getTableDescriptor(TableName.valueOf(tableName));
+        TableDescriptor tableDesc = admin.getDescriptor(TableName.valueOf(tableName));
         for (ColumnFamilyDescriptor colDesc : tableDesc.getColumnFamilies()) {
-            assertEquals(ttl,Integer.parseInt(Bytes.toString(colDesc.getValue(Bytes.toBytes(TxConstants.PROPERTY_TTL)))));
             assertEquals(ColumnFamilyDescriptorBuilder.DEFAULT_TTL,colDesc.getTimeToLive());
         }
     }
