@@ -171,11 +171,11 @@ public class TaskMetaDataEndpointTest {
         CoprocessorRpcUtils.BlockingRpcCallback<MetaDataProtos.MetaDataResponse> rpcCallback =
             new CoprocessorRpcUtils.BlockingRpcCallback<>();
         Mockito.doNothing().when(region).mutateRowsWithLocks(
-            Mockito.anyCollectionOf(Mutation.class), Mockito.any(), Mockito.anyLong(),
+            Mockito.anyCollection(), Mockito.any(), Mockito.anyLong(),
             Mockito.anyLong());
         taskMetaDataEndpoint.upsertTaskDetails(controller, request, rpcCallback);
         Mockito.verify(region, Mockito.times(1)).mutateRowsWithLocks(
-            Mockito.anyCollectionOf(Mutation.class), Mockito.any(), Mockito.anyLong(),
+            Mockito.anyCollection(), Mockito.any(), Mockito.anyLong(),
             Mockito.anyLong());
     }
 
@@ -190,11 +190,11 @@ public class TaskMetaDataEndpointTest {
         CoprocessorRpcUtils.BlockingRpcCallback<MetaDataProtos.MetaDataResponse> rpcCallback =
             new CoprocessorRpcUtils.BlockingRpcCallback<>();
         Mockito.doThrow(IOException.class).when(region).mutateRowsWithLocks(
-            Mockito.anyCollectionOf(Mutation.class), Mockito.any(), Mockito.anyLong(),
+            Mockito.anyCollection(), Mockito.any(), Mockito.anyLong(),
             Mockito.anyLong());
         taskMetaDataEndpoint.upsertTaskDetails(controller, request, rpcCallback);
         Mockito.verify(region, Mockito.times(1)).mutateRowsWithLocks(
-            Mockito.anyCollectionOf(Mutation.class), Mockito.any(), Mockito.anyLong(),
+            Mockito.anyCollection(), Mockito.any(), Mockito.anyLong(),
             Mockito.anyLong());
         assertEquals(MetaDataProtos.MutationCode.UNABLE_TO_UPSERT_TASK,
             rpcCallback.get().getReturnCode());
