@@ -87,12 +87,12 @@ public class QueryPlanTest extends BaseConnectionlessQueryTest {
 
                 "SELECT count(*) FROM atable",
                 "CLIENT PARALLEL 1-WAY FULL SCAN OVER ATABLE\n" + 
-                "    SERVER FILTER BY FIRST KEY ONLY\n" + 
+                "    SERVER FILTER BY FIRST KEY ONLY\n" +
                 "    SERVER AGGREGATE INTO SINGLE ROW",
 
                 "SELECT count(*) FROM atable WHERE organization_id='000000000000001' AND SUBSTR(entity_id,1,3) > '002' AND SUBSTR(entity_id,1,3) <= '003'",
                 "CLIENT PARALLEL 1-WAY RANGE SCAN OVER ATABLE ['000000000000001','003            '] - ['000000000000001','004            ']\n" + 
-                "    SERVER FILTER BY FIRST KEY ONLY\n" + 
+                "    SERVER FILTER BY FIRST KEY ONLY\n" +
                 "    SERVER AGGREGATE INTO SINGLE ROW",
 
                 "SELECT a_string FROM atable WHERE organization_id='000000000000001' AND SUBSTR(entity_id,1,3) > '002' AND SUBSTR(entity_id,1,3) <= '003'",
@@ -247,9 +247,13 @@ public class QueryPlanTest extends BaseConnectionlessQueryTest {
             String query = "select * from foo where a = 'a' and b >= timestamp '2016-01-28 00:00:00' and b < timestamp '2016-01-29 00:00:00'";
             ResultSet rs = conn.createStatement().executeQuery("EXPLAIN " + query);
             String queryPlan = QueryUtil.getExplainPlan(rs);
+            // For real connection CQSI, the result is supposed to be 20-WAY RANGE SCAN, however
+            // for connection-less impl, since we retrieve region locations for 20 splits and each
+            // time we get all region locations due to connection-less specific impl, we get
+            // 20*20 = 400-WAY RANGE SCAN.
             assertEquals(
-                    "CLIENT PARALLEL 20-WAY RANGE SCAN OVER FOO [0,'a',~'2016-01-28 23:59:59.999'] - [19,'a',~'2016-01-28 00:00:00.000']\n" + 
-                    "    SERVER FILTER BY FIRST KEY ONLY\n" + 
+                    "CLIENT PARALLEL 400-WAY RANGE SCAN OVER FOO [X'00','a',~'2016-01-28 23:59:59.999'] - [X'13','a',~'2016-01-28 00:00:00.000']\n" +
+                    "    SERVER FILTER BY FIRST KEY ONLY\n" +
                     "CLIENT MERGE SORT", queryPlan);
         } finally {
             conn.close();
@@ -273,8 +277,12 @@ public class QueryPlanTest extends BaseConnectionlessQueryTest {
             String query = "select * from " + tableName + " where a = 'a' and b >= timestamp '2016-01-28 00:00:00' and b < timestamp '2016-01-29 00:00:00'";
             ResultSet rs = conn.createStatement().executeQuery("EXPLAIN " + query);
             String queryPlan = QueryUtil.getExplainPlan(rs);
+            // For real connection CQSI, the result is supposed to be 20-WAY RANGE SCAN, however
+            // for connection-less impl, since we retrieve region locations for 20 splits and each
+            // time we get all region locations due to connection-less specific impl, we get
+            // 20*20 = 400-WAY RANGE SCAN.
             assertEquals(
-                    "CLIENT PARALLEL 20-WAY ROUND ROBIN RANGE SCAN OVER " + tableName + " [0,'a',~'2016-01-28 23:59:59.999'] - [19,'a',~'2016-01-28 00:00:00.000']\n" + 
+                    "CLIENT PARALLEL 400-WAY ROUND ROBIN RANGE SCAN OVER " + tableName + " [X'00','a',~'2016-01-28 23:59:59.999'] - [X'13','a',~'2016-01-28 00:00:00.000']\n" +
                     "    SERVER FILTER BY FIRST KEY ONLY", queryPlan);
         } finally {
             conn.close();
