@@ -25,7 +25,7 @@ import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableMap;
 
