@@ -57,16 +57,20 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
+import java.util.stream.Collectors;
 
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellScanner;
 import org.apache.hadoop.hbase.CellUtil;
+import org.apache.hadoop.hbase.CompareOperator;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
 import org.apache.hadoop.hbase.client.CompactionState;
+import org.apache.hadoop.hbase.client.CoprocessorDescriptor;
+import org.apache.hadoop.hbase.client.CoprocessorDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Delete;
 
 import org.apache.hadoop.hbase.client.Get;
@@ -78,7 +82,6 @@ import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.client.coprocessor.Batch;
-import org.apache.hadoop.hbase.filter.CompareFilter.CompareOp;
 import org.apache.hadoop.hbase.filter.Filter;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.ipc.CoprocessorRpcUtils.BlockingRpcCallback;
@@ -148,7 +151,6 @@ import org.apache.phoenix.schema.stats.GuidePostsInfo;
 import org.apache.phoenix.schema.stats.GuidePostsKey;
 import org.apache.phoenix.schema.tuple.Tuple;
 import org.apache.phoenix.schema.types.PDataType;
-import org.apache.phoenix.transaction.TransactionFactory;
 import org.junit.Assert;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -343,7 +345,7 @@ public class TestUtil {
         return BigDecimal.valueOf(sum).divide(BigDecimal.valueOf(count), PDataType.DEFAULT_MATH_CONTEXT);
     }
 
-    public static Expression constantComparison(CompareOp op, PColumn c, Object o) {
+    public static Expression constantComparison(CompareOperator op, PColumn c, Object o) {
         return new ComparisonExpression(Arrays.<Expression>asList(new KeyValueColumnExpression(c), LiteralExpression.newConstant(o)), op);
     }
 
@@ -355,7 +357,7 @@ public class TestUtil {
         return new RowKeyColumnExpression(c, new RowKeyValueAccessor(columns, columns.indexOf(c)));
     }
 
-    public static Expression constantComparison(CompareOp op, Expression e, Object o) {
+    public static Expression constantComparison(CompareOperator op, Expression e, Object o) {
         return new ComparisonExpression(Arrays.asList(e, LiteralExpression.newConstant(o)), op);
     }
 
@@ -389,7 +391,7 @@ public class TestUtil {
         return new SubstrFunction(Arrays.asList(e, LiteralExpression.newConstant(offset), LiteralExpression.newConstant(null)));
     }
 
-    public static Expression columnComparison(CompareOp op, Expression c1, Expression c2) {
+    public static Expression columnComparison(CompareOperator op, Expression c1, Expression c2) {
         return new ComparisonExpression(Arrays.<Expression>asList(c1, c2), op);
     }
 
@@ -808,6 +810,11 @@ public class TestUtil {
         conn.createStatement().execute(ddl);
     }
 
+    public static void flush(HBaseTestingUtility utility, TableName table) throws IOException {
+        Admin admin = utility.getAdmin();
+        admin.flush(table);
+    }
+
     public static void majorCompact(HBaseTestingUtility utility, TableName table)
         throws IOException, InterruptedException {
         long compactionRequestedSCN = EnvironmentEdgeManager.currentTimeMillis();
@@ -879,8 +886,8 @@ public class TestUtil {
             while (!compactionDone) {
                 Thread.sleep(6000L);
                 Scan scan = new Scan();
-                scan.setStartRow(markerRowKey);
-                scan.setStopRow(Bytes.add(markerRowKey, new byte[]{0}));
+                scan.withStartRow(markerRowKey);
+                scan.withStopRow(Bytes.add(markerRowKey, new byte[]{0}));
                 scan.setRaw(true);
         
                 try (Table htableForRawScan = services.getTable(Bytes.toBytes(tableName))) {
@@ -921,22 +928,26 @@ public class TestUtil {
     public static void dumpTable(Table table) throws IOException {
         System.out.println("************ dumping " + table + " **************");
         Scan s = new Scan();
-        s.setRaw(true);;
+        s.setRaw(true);
         s.readAllVersions();
+        int cellCount = 0;
+        int rowCount = 0;
         try (ResultScanner scanner = table.getScanner(s)) {
             Result result = null;
             while ((result = scanner.next()) != null) {
+                rowCount++;
                 CellScanner cellScanner = result.cellScanner();
                 Cell current = null;
                 while (cellScanner.advance()) {
                     current = cellScanner.current();
                     System.out.println(current + " column= " +
-                        Bytes.toString(CellUtil.cloneQualifier(current)) +
+                        Bytes.toStringBinary(CellUtil.cloneQualifier(current)) +
                         " val=" + Bytes.toStringBinary(CellUtil.cloneValue(current)));
+                    cellCount++;
                 }
             }
         }
-        System.out.println("-----------------------------------------------");
+        System.out.println("----- Row count: " + rowCount + " Cell count: " + cellCount + " -----");
     }
 
     public static int getRawRowCount(Table table) throws IOException {
@@ -947,7 +958,7 @@ public class TestUtil {
         Scan s = new Scan();
         s.setRaw(isRaw);
         ;
-        s.setMaxVersions();
+        s.readAllVersions();
         int rows = 0;
         try (ResultScanner scanner = table.getScanner(s)) {
             Result result = null;
@@ -967,7 +978,7 @@ public class TestUtil {
         Scan s = new Scan();
         s.setRaw(isRaw);
         ;
-        s.setMaxVersions();
+        s.readAllVersions();
 
         CellCount cellCount = new CellCount();
         try (ResultScanner scanner = table.getScanner(s)) {
@@ -1010,10 +1021,10 @@ public class TestUtil {
             System.out.println("************ dumping index status for " + indexName + " **************");
             Scan s = new Scan();
             s.setRaw(true);
-            s.setMaxVersions();
+            s.readAllVersions();
             byte[] startRow = SchemaUtil.getTableKeyFromFullName(indexName);
-            s.setStartRow(startRow);
-            s.setStopRow(ByteUtil.nextKey(ByteUtil.concat(startRow, QueryConstants.SEPARATOR_BYTE_ARRAY)));
+            s.withStartRow(startRow);
+            s.withStopRow(ByteUtil.nextKey(ByteUtil.concat(startRow, QueryConstants.SEPARATOR_BYTE_ARRAY)));
             try (ResultScanner scanner = table.getScanner(s)) {
                 Result result = null;
                 while ((result = scanner.next()) != null) {
@@ -1186,9 +1197,11 @@ public class TestUtil {
         ConnectionQueryServices services = conn.unwrap(PhoenixConnection.class).getQueryServices();
         TableDescriptor descriptor = services.getTableDescriptor(Bytes.toBytes(tableName));
         TableDescriptorBuilder descriptorBuilder = null;
-		if (!descriptor.getCoprocessors().contains(coprocessorClass.getName())) {
+		if (!descriptor.getCoprocessorDescriptors().stream().map(CoprocessorDescriptor::getClassName)
+                .collect(Collectors.toList()).contains(coprocessorClass.getName())) {
 		    descriptorBuilder=TableDescriptorBuilder.newBuilder(descriptor);
-		    descriptorBuilder.addCoprocessor(coprocessorClass.getName(), null, priority, null);
+		    descriptorBuilder.setCoprocessor(
+                    CoprocessorDescriptorBuilder.newBuilder(coprocessorClass.getName()).setPriority(priority).build());
 		}else{
 			return;
 		}
@@ -1214,7 +1227,8 @@ public class TestUtil {
         ConnectionQueryServices services = conn.unwrap(PhoenixConnection.class).getQueryServices();
         TableDescriptor descriptor = services.getTableDescriptor(Bytes.toBytes(tableName));
         TableDescriptorBuilder descriptorBuilder = null;
-        if (descriptor.getCoprocessors().contains(coprocessorClass.getName())) {
+        if (descriptor.getCoprocessorDescriptors().stream().map(CoprocessorDescriptor::getClassName)
+                .collect(Collectors.toList()).contains(coprocessorClass.getName())) {
             descriptorBuilder=TableDescriptorBuilder.newBuilder(descriptor);
             descriptorBuilder.removeCoprocessor(coprocessorClass.getName());
         }else{
@@ -1238,7 +1252,7 @@ public class TestUtil {
         }
     }
 
-    public static boolean compare(CompareOp op, ImmutableBytesWritable lhsOutPtr, ImmutableBytesWritable rhsOutPtr) {
+    public static boolean compare(CompareOperator op, ImmutableBytesWritable lhsOutPtr, ImmutableBytesWritable rhsOutPtr) {
         int compareResult = Bytes.compareTo(lhsOutPtr.get(), lhsOutPtr.getOffset(), lhsOutPtr.getLength(), rhsOutPtr.get(), rhsOutPtr.getOffset(), rhsOutPtr.getLength());
         return ByteUtil.compare(op, compareResult);
     }
@@ -1265,8 +1279,7 @@ public class TestUtil {
                 if (realValue == null) {
                     assertNull("rowIndex:[" + rowIndex + "],columnIndex:[" + columnIndex + "]", expectedValue);
                 } else {
-                    assertEquals("rowIndex:[" + rowIndex + "],columnIndex:[" + columnIndex + "],realValue:[" +
-                            realValue + "],expectedValue:[" + expectedValue + "]",
+                    assertEquals("rowIndex:[" + rowIndex + "],columnIndex:[" + columnIndex + "]",
                         expectedValue,
                         realValue
                     );
@@ -1276,30 +1289,6 @@ public class TestUtil {
         assertTrue(!rs.next());
     }
 
-    public static Collection<Object[]> filterTxParamData(Collection<Object[]> data, int index) {
-        boolean runAllTests = true;
-        boolean runNoTests = true;
-
-        for (TransactionFactory.Provider provider : TransactionFactory.Provider.values()) {
-            runAllTests &= provider.runTests();
-            runNoTests &= !provider.runTests();
-        }
-        if (runNoTests) {
-            return Collections.emptySet();
-        }
-        if (runAllTests) {
-            return data;
-        }
-        List<Object[]> filteredData = Lists.newArrayListWithExpectedSize(data.size());
-        for (Object[] params : data) {
-            String provider = (String) params[index];
-            if (provider == null || TransactionFactory.Provider.valueOf(provider).runTests()) {
-                filteredData.add(params);
-            }
-        }
-        return filteredData;
-    }
-
     /**
      * Find a random free port in localhost for binding.
      *
@@ -1365,7 +1354,7 @@ public class TestUtil {
         throws SQLException, IOException {
         Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin();
         TableDescriptor td = admin.getDescriptor(tableName);
-        return td.getColumnFamily(QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES);
+        return td.getColumnFamilies()[0];
     }
 
     public static void assertRawRowCount(Connection conn, TableName table, int expectedRowCount)
