@@ -20,6 +20,7 @@ package org.apache.phoenix.compat.hbase;
 import java.io.IOException;
 
 import org.apache.hadoop.hbase.client.RegionLocator;
+import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.RowMutations;
 import org.apache.hadoop.hbase.client.Table;
 
@@ -37,7 +38,7 @@ public abstract class CompatDelegateHTable implements Table {
     }
 
     @Override
-    public void mutateRow(RowMutations rm) throws IOException {
-        delegate.mutateRow(rm);
+    public Result mutateRow(RowMutations rm) throws IOException {
+        return delegate.mutateRow(rm);
     }
 }
