@@ -25,6 +25,7 @@ import org.junit.contrib.java.lang.system.ExpectedSystemExit;
 import java.util.Properties;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
 
 public class PherfTest {
     @Rule
@@ -45,6 +46,21 @@ public class PherfTest {
         Pherf.main(args);
     }
 
+    @Test
+    public void testLongOptions() throws Exception{
+        String extension = ".sql";
+        String args = "testArgs";
+        Long numericArg = 15l;
+
+        String[] longOptionArgs = {"--schemaFile",PherfConstants.SCHEMA_ROOT_PATTERN + extension,"--disableSchemaApply","--disableRuntimeResult","--listFiles","--scenarioFile",args,"--scenarioName",args,"--useAverageCompareType"};
+        //Asset that No Exception is thrown, ParseException is thrown in case of invalid option
+        assertNotNull(new Pherf(longOptionArgs));
+
+        String[] otherLongOptionArgs = {"--drop",args,"--monitorFrequency",args,"--rowCountOverride",numericArg.toString(),"--hint",args,"--log_per_nrows",numericArg.toString(),"--diff","--export","--writerThreadSize",args,"--stats","--label",args,"--compare",args};
+        //Asset that No Exception is thrown, ParseException is thrown in case of invalid option
+        assertNotNull(new Pherf(otherLongOptionArgs));
+    }
+
     @Test
     public void testDefaultLogPerNRowsArgument() throws Exception {
         String[] args = {"-listFiles"};
